{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# MMEngine 快速上手\n",
    "\n",
    "参考：[MMEngine 快速上手](https://mmengine.readthedocs.io/zh-cn/latest/get_started/15_minutes.html)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## 构建模型\n",
    "\n",
    "首先，需要构建 MMEngine 模型，约定这个模型应当继承 {class}`~mmengine.model.BaseModel`，并且其 `forward` 方法除了接受来自数据集的若干参数外，还需要接受额外的参数 `mode`：对于训练，需要 `mode` 接受字符串 `\"loss\"`，并返回包含 `\"loss\"` 字段的字典；对于验证，需要 `mode` 接受字符串 `\"predict\"`，并返回同时包含预测信息和真实信息的结果。"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [],
   "source": [
    "import torch.nn.functional as F\n",
    "import torch\n",
    "from torch import nn\n",
    "import torchvision\n",
    "from mmengine.model import BaseModel\n",
    "\n",
    "\n",
    "class MMResNet50(BaseModel):\n",
    "    def __init__(self, data_preprocessor: dict|nn.Module|None = None,\n",
    "                 init_cfg: dict|None = None):\n",
    "        super().__init__(data_preprocessor=data_preprocessor, init_cfg=init_cfg)\n",
    "        self.resnet = torchvision.models.resnet50()\n",
    "\n",
    "    def forward(self, inputs: torch.Tensor,\n",
    "                data_samples: list|list = None,\n",
    "                mode: str = 'tensor') -> dict[str, torch.Tensor] | list:\n",
    "        x = self.resnet(inputs)\n",
    "        if mode == 'loss':\n",
    "            return {'loss': F.cross_entropy(x, data_samples)}\n",
    "        elif mode == 'predict':\n",
    "            return x, data_samples\n",
    "        else:\n",
    "            return x"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## 构建数据集和数据加载器\n",
    "\n",
    "其次，需要构建训练和验证所需要的数据集 ({class}`~torch.utils.data.Dataset`)和数据加载器 ({class}`~torch.utils.data.DataLoader`)。 对于基础的训练和验证功能，可以直接使用符合 PyTorch 标准的数据加载器和数据集。"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [],
   "source": [
    "from pathlib import Path\n",
    "\n",
    "temp_dir = Path(\".temp\")\n",
    "temp_dir.mkdir(exist_ok=True) # 创建缓存目录"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Downloading https://www.cs.toronto.edu/~kriz/cifar-10-python.tar.gz to .temp/data/cifar10/cifar-10-python.tar.gz\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "100%|██████████| 170M/170M [04:18<00:00, 659kB/s]  \n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Extracting .temp/data/cifar10/cifar-10-python.tar.gz to .temp/data/cifar10\n",
      "Files already downloaded and verified\n"
     ]
    }
   ],
   "source": [
    "import torchvision.transforms as transforms\n",
    "from torch.utils.data import DataLoader\n",
    "\n",
    "norm_cfg = dict(mean=[0.491, 0.482, 0.447], std=[0.202, 0.199, 0.201])\n",
    "train_dataloader = DataLoader(\n",
    "    batch_size=32,\n",
    "    shuffle=True,\n",
    "    dataset=torchvision.datasets.CIFAR10(\n",
    "        temp_dir/'data/cifar10',\n",
    "        train=True,\n",
    "        download=True,\n",
    "        transform=transforms.Compose([\n",
    "            transforms.RandomCrop(32, padding=4),\n",
    "            transforms.RandomHorizontalFlip(),\n",
    "            transforms.ToTensor(),\n",
    "            transforms.Normalize(**norm_cfg)\n",
    "        ]))\n",
    ")\n",
    "val_dataloader = DataLoader(\n",
    "    batch_size=32,\n",
    "    shuffle=False,\n",
    "    dataset=torchvision.datasets.CIFAR10(\n",
    "        temp_dir/'data/cifar10',\n",
    "        train=False,\n",
    "        download=True,\n",
    "        transform=transforms.Compose([\n",
    "            transforms.ToTensor(),\n",
    "            transforms.Normalize(**norm_cfg)\n",
    "        ]))\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## 构建评测指标\n",
    "\n",
    "为了进行验证和测试，需要定义模型推理结果的评测指标。\n",
    "\n",
    "约定评测指标需要继承 {class}`~mmengine.evaluator.BaseMetric`，并实现 `process` 和 `compute_metrics` 方法。其中 `process` 方法接受数据集的输出和模型 `mode=\"predict\"` 时的输出，此时的数据为单个批次的数据，对这一批次的数据进行处理后，保存信息至 `self.results` 属性。而 `compute_metrics` 接受 `results` 参数，这一参数的输入为 `process` 中保存的所有信息（如果是分布式环境，`results` 中为已收集的，包括各个进程 `process` 保存信息的结果），利用这些信息计算并返回保存有评测指标结果的字典"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "from typing import Any, Sequence\n",
    "from mmengine.evaluator import BaseMetric\n",
    "\n",
    "class Accuracy(BaseMetric):\n",
    "    def process(self, data_batch: Any, data_samples: Sequence[dict])->None:\n",
    "        \"\"\"\n",
    "        处理一批数据样本及其预测结果。处理后的结果应存储在`self.results`中，这将在所有批次处理完毕后用于计算指标。\n",
    "\n",
    "        Args:\n",
    "            data_batch: 从数据加载器获取的一批数据。\n",
    "            data_samples: 模型输出的一批结果。\n",
    "        \"\"\"\n",
    "        score, gt = data_samples\n",
    "        # 将一个批次的中间结果保存至 `self.results`\n",
    "        self.results.append({\n",
    "            'batch_size': len(gt),\n",
    "            'correct': (score.argmax(dim=1) == gt).sum().cpu(),\n",
    "        })\n",
    "\n",
    "    def compute_metrics(self, results):\n",
    "        total_correct = sum(item['correct'] for item in results)\n",
    "        total_size = sum(item['batch_size'] for item in results)\n",
    "        # 返回保存有评测指标结果的字典，其中键为指标名称\n",
    "        return dict(accuracy=100 * total_correct / total_size)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## 构建执行器并执行任务\n",
    "\n",
    "最后，利用构建好的模型，数据加载器，评测指标构建执行器 ({class}`~mmengine.runner.Runner`)，同时在其中配置 优化器、工作路径、训练与验证配置等选项，即可通过调用执行器的 {meth}`~mmengine.runner.Runner.train` 方法启动训练："
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "tags": [
     "hide-output"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "11/16 19:30:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - \n",
      "------------------------------------------------------------\n",
      "System environment:\n",
      "    sys.platform: linux\n",
      "    Python: 3.12.2 | packaged by conda-forge | (main, Feb 16 2024, 20:50:58) [GCC 12.3.0]\n",
      "    CUDA available: True\n",
      "    MUSA available: False\n",
      "    numpy_random_seed: 798167336\n",
      "    GPU 0: NVIDIA GeForce RTX 3090\n",
      "    GPU 1: NVIDIA GeForce RTX 2080 Ti\n",
      "    CUDA_HOME: /media/pc/data/lxw/envs/anaconda3x/envs/xxx\n",
      "    NVCC: Cuda compilation tools, release 12.6, V12.6.20\n",
      "    GCC: gcc (conda-forge gcc 12.4.0-0) 12.4.0\n",
      "    PyTorch: 2.5.0\n",
      "    PyTorch compiling details: PyTorch built with:\n",
      "  - GCC 9.3\n",
      "  - C++ Version: 201703\n",
      "  - Intel(R) oneAPI Math Kernel Library Version 2023.1-Product Build 20230303 for Intel(R) 64 architecture applications\n",
      "  - Intel(R) MKL-DNN v3.5.3 (Git Hash 66f0cb9eb66affd2da3bf5f8d897376f04aae6af)\n",
      "  - OpenMP 201511 (a.k.a. OpenMP 4.5)\n",
      "  - LAPACK is enabled (usually provided by MKL)\n",
      "  - NNPACK is enabled\n",
      "  - CPU capability usage: AVX2\n",
      "  - CUDA Runtime 12.4\n",
      "  - NVCC architecture flags: -gencode;arch=compute_50,code=sm_50;-gencode;arch=compute_60,code=sm_60;-gencode;arch=compute_61,code=sm_61;-gencode;arch=compute_70,code=sm_70;-gencode;arch=compute_75,code=sm_75;-gencode;arch=compute_80,code=sm_80;-gencode;arch=compute_86,code=sm_86;-gencode;arch=compute_90,code=sm_90\n",
      "  - CuDNN 90.1\n",
      "  - Magma 2.6.1\n",
      "  - Build settings: BLAS_INFO=mkl, BUILD_TYPE=Release, CUDA_VERSION=12.4, CUDNN_VERSION=9.1.0, CXX_COMPILER=/opt/rh/devtoolset-9/root/usr/bin/c++, CXX_FLAGS= -D_GLIBCXX_USE_CXX11_ABI=0 -fabi-version=11 -fvisibility-inlines-hidden -DUSE_PTHREADPOOL -DNDEBUG -DUSE_KINETO -DLIBKINETO_NOROCTRACER -DLIBKINETO_NOXPUPTI=ON -DUSE_FBGEMM -DUSE_PYTORCH_QNNPACK -DUSE_XNNPACK -DSYMBOLICATE_MOBILE_DEBUG_HANDLE -O2 -fPIC -Wall -Wextra -Werror=return-type -Werror=non-virtual-dtor -Werror=bool-operation -Wnarrowing -Wno-missing-field-initializers -Wno-type-limits -Wno-array-bounds -Wno-unknown-pragmas -Wno-unused-parameter -Wno-strict-overflow -Wno-strict-aliasing -Wno-stringop-overflow -Wsuggest-override -Wno-psabi -Wno-error=old-style-cast -Wno-missing-braces -fdiagnostics-color=always -faligned-new -Wno-unused-but-set-variable -Wno-maybe-uninitialized -fno-math-errno -fno-trapping-math -Werror=format -Wno-stringop-overflow, LAPACK_INFO=mkl, PERF_WITH_AVX=1, PERF_WITH_AVX2=1, TORCH_VERSION=2.5.0, USE_CUDA=ON, USE_CUDNN=ON, USE_CUSPARSELT=1, USE_EXCEPTION_PTR=1, USE_GFLAGS=OFF, USE_GLOG=OFF, USE_GLOO=ON, USE_MKL=ON, USE_MKLDNN=ON, USE_MPI=OFF, USE_NCCL=ON, USE_NNPACK=ON, USE_OPENMP=ON, USE_ROCM=OFF, USE_ROCM_KERNEL_ASSERT=OFF, \n",
      "\n",
      "    TorchVision: 0.20.0\n",
      "    OpenCV: 4.10.0\n",
      "    MMEngine: 0.10.5\n",
      "\n",
      "Runtime environment:\n",
      "    dist_cfg: {'backend': 'nccl'}\n",
      "    seed: 798167336\n",
      "    Distributed launcher: none\n",
      "    Distributed training: False\n",
      "    GPU number: 1\n",
      "------------------------------------------------------------\n",
      "\n",
      "11/16 19:30:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Distributed training is not used, all SyncBatchNorm (SyncBN) layers in the model will be automatically reverted to BatchNormXd layers if they are used.\n",
      "11/16 19:30:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Hooks will be executed in the following order:\n",
      "before_run:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      " -------------------- \n",
      "before_train:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(VERY_LOW    ) CheckpointHook                     \n",
      " -------------------- \n",
      "before_train_epoch:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(NORMAL      ) DistSamplerSeedHook                \n",
      " -------------------- \n",
      "before_train_iter:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      " -------------------- \n",
      "after_train_iter:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      "(LOW         ) ParamSchedulerHook                 \n",
      "(VERY_LOW    ) CheckpointHook                     \n",
      " -------------------- \n",
      "after_train_epoch:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(LOW         ) ParamSchedulerHook                 \n",
      "(VERY_LOW    ) CheckpointHook                     \n",
      " -------------------- \n",
      "before_val:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      " -------------------- \n",
      "before_val_epoch:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      " -------------------- \n",
      "before_val_iter:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      " -------------------- \n",
      "after_val_iter:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      " -------------------- \n",
      "after_val_epoch:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      "(LOW         ) ParamSchedulerHook                 \n",
      "(VERY_LOW    ) CheckpointHook                     \n",
      " -------------------- \n",
      "after_val:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      " -------------------- \n",
      "after_train:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(VERY_LOW    ) CheckpointHook                     \n",
      " -------------------- \n",
      "before_test:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      " -------------------- \n",
      "before_test_epoch:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      " -------------------- \n",
      "before_test_iter:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      " -------------------- \n",
      "after_test_iter:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      " -------------------- \n",
      "after_test_epoch:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      " -------------------- \n",
      "after_test:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      " -------------------- \n",
      "after_run:\n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      " -------------------- \n",
      "11/16 19:30:32 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - Dataset CIFAR10 has no metainfo. ``dataset_meta`` in visualizer will be None.\n",
      "11/16 19:30:32 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - The prefix is not set in metric class Accuracy.\n",
      "11/16 19:30:32 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - Dataset CIFAR10 has no metainfo. ``dataset_meta`` in evaluator, metric and visualizer will be None.\n",
      "11/16 19:30:32 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - \"FileClient\" will be deprecated in future. Please use io functions in https://mmengine.readthedocs.io/en/latest/api/fileio.html#file-io\n",
      "11/16 19:30:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Checkpoints will be saved to /media/pc/data/lxw/ai/torch-book/doc/mmengine/.temp/work_dir.\n",
      "11/16 19:30:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  10/1563]  lr: 1.0000e-03  eta: 0:06:52  time: 0.0528  data_time: 0.0136  memory: 583  loss: 5.2429\n",
      "11/16 19:30:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  20/1563]  lr: 1.0000e-03  eta: 0:07:47  time: 0.0672  data_time: 0.0246  memory: 583  loss: 2.7109\n",
      "11/16 19:30:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  30/1563]  lr: 1.0000e-03  eta: 0:07:38  time: 0.0566  data_time: 0.0156  memory: 583  loss: 2.8172\n",
      "11/16 19:30:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  40/1563]  lr: 1.0000e-03  eta: 0:07:33  time: 0.0567  data_time: 0.0155  memory: 583  loss: 2.7161\n",
      "11/16 19:30:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  50/1563]  lr: 1.0000e-03  eta: 0:07:30  time: 0.0570  data_time: 0.0157  memory: 583  loss: 2.5933\n",
      "11/16 19:30:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  60/1563]  lr: 1.0000e-03  eta: 0:07:28  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.5723\n",
      "11/16 19:30:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  70/1563]  lr: 1.0000e-03  eta: 0:07:26  time: 0.0567  data_time: 0.0156  memory: 583  loss: 2.6657\n",
      "11/16 19:30:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  80/1563]  lr: 1.0000e-03  eta: 0:07:25  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.8928\n",
      "11/16 19:30:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  90/1563]  lr: 1.0000e-03  eta: 0:07:24  time: 0.0568  data_time: 0.0157  memory: 583  loss: 2.7148\n",
      "11/16 19:30:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 100/1563]  lr: 1.0000e-03  eta: 0:07:22  time: 0.0566  data_time: 0.0156  memory: 583  loss: 2.6429\n",
      "11/16 19:30:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 110/1563]  lr: 1.0000e-03  eta: 0:07:22  time: 0.0572  data_time: 0.0159  memory: 583  loss: 2.4578\n",
      "11/16 19:30:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 120/1563]  lr: 1.0000e-03  eta: 0:07:21  time: 0.0572  data_time: 0.0159  memory: 583  loss: 2.5217\n",
      "11/16 19:30:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 130/1563]  lr: 1.0000e-03  eta: 0:07:20  time: 0.0569  data_time: 0.0157  memory: 583  loss: 2.4902\n",
      "11/16 19:30:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 140/1563]  lr: 1.0000e-03  eta: 0:07:19  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.5046\n",
      "11/16 19:30:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 150/1563]  lr: 1.0000e-03  eta: 0:07:19  time: 0.0570  data_time: 0.0156  memory: 583  loss: 2.5468\n",
      "11/16 19:30:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 160/1563]  lr: 1.0000e-03  eta: 0:07:18  time: 0.0569  data_time: 0.0157  memory: 583  loss: 2.5345\n",
      "11/16 19:30:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 170/1563]  lr: 1.0000e-03  eta: 0:07:17  time: 0.0567  data_time: 0.0156  memory: 583  loss: 2.5123\n",
      "11/16 19:30:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 180/1563]  lr: 1.0000e-03  eta: 0:07:16  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.4850\n",
      "11/16 19:30:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 190/1563]  lr: 1.0000e-03  eta: 0:07:16  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.4499\n",
      "11/16 19:30:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 200/1563]  lr: 1.0000e-03  eta: 0:07:15  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.6277\n",
      "11/16 19:30:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 210/1563]  lr: 1.0000e-03  eta: 0:07:14  time: 0.0572  data_time: 0.0158  memory: 583  loss: 2.4470\n",
      "11/16 19:30:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 220/1563]  lr: 1.0000e-03  eta: 0:07:14  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.5172\n",
      "11/16 19:30:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 230/1563]  lr: 1.0000e-03  eta: 0:07:13  time: 0.0571  data_time: 0.0157  memory: 583  loss: 2.4071\n",
      "11/16 19:30:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 240/1563]  lr: 1.0000e-03  eta: 0:07:12  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.3784\n",
      "11/16 19:30:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 250/1563]  lr: 1.0000e-03  eta: 0:07:12  time: 0.0571  data_time: 0.0157  memory: 583  loss: 2.3364\n",
      "11/16 19:30:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 260/1563]  lr: 1.0000e-03  eta: 0:07:11  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.4262\n",
      "11/16 19:30:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 270/1563]  lr: 1.0000e-03  eta: 0:07:10  time: 0.0570  data_time: 0.0157  memory: 583  loss: 2.4239\n",
      "11/16 19:30:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 280/1563]  lr: 1.0000e-03  eta: 0:07:10  time: 0.0569  data_time: 0.0157  memory: 583  loss: 2.6525\n",
      "11/16 19:30:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 290/1563]  lr: 1.0000e-03  eta: 0:07:09  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.5649\n",
      "11/16 19:30:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 300/1563]  lr: 1.0000e-03  eta: 0:07:09  time: 0.0568  data_time: 0.0155  memory: 583  loss: 2.4449\n",
      "11/16 19:30:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 310/1563]  lr: 1.0000e-03  eta: 0:07:08  time: 0.0570  data_time: 0.0157  memory: 583  loss: 2.4234\n",
      "11/16 19:30:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 320/1563]  lr: 1.0000e-03  eta: 0:07:07  time: 0.0569  data_time: 0.0155  memory: 583  loss: 2.4709\n",
      "11/16 19:30:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 330/1563]  lr: 1.0000e-03  eta: 0:07:07  time: 0.0570  data_time: 0.0156  memory: 583  loss: 2.3999\n",
      "11/16 19:30:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 340/1563]  lr: 1.0000e-03  eta: 0:07:06  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.3403\n",
      "11/16 19:30:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 350/1563]  lr: 1.0000e-03  eta: 0:07:05  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.4029\n",
      "11/16 19:30:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 360/1563]  lr: 1.0000e-03  eta: 0:07:05  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.1956\n",
      "11/16 19:30:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 370/1563]  lr: 1.0000e-03  eta: 0:07:04  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.3607\n",
      "11/16 19:30:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 380/1563]  lr: 1.0000e-03  eta: 0:07:04  time: 0.0568  data_time: 0.0155  memory: 583  loss: 2.2534\n",
      "11/16 19:30:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 390/1563]  lr: 1.0000e-03  eta: 0:07:04  time: 0.0622  data_time: 0.0205  memory: 583  loss: 2.3954\n",
      "11/16 19:30:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 400/1563]  lr: 1.0000e-03  eta: 0:07:03  time: 0.0569  data_time: 0.0155  memory: 583  loss: 2.4549\n",
      "11/16 19:30:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 410/1563]  lr: 1.0000e-03  eta: 0:07:03  time: 0.0572  data_time: 0.0159  memory: 583  loss: 2.3724\n",
      "11/16 19:30:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 420/1563]  lr: 1.0000e-03  eta: 0:07:02  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.3348\n",
      "11/16 19:30:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 430/1563]  lr: 1.0000e-03  eta: 0:07:02  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.2779\n",
      "11/16 19:30:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 440/1563]  lr: 1.0000e-03  eta: 0:07:01  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.2766\n",
      "11/16 19:30:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 450/1563]  lr: 1.0000e-03  eta: 0:07:00  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.4431\n",
      "11/16 19:30:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 460/1563]  lr: 1.0000e-03  eta: 0:07:00  time: 0.0567  data_time: 0.0155  memory: 583  loss: 2.3707\n",
      "11/16 19:30:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 470/1563]  lr: 1.0000e-03  eta: 0:06:59  time: 0.0574  data_time: 0.0159  memory: 583  loss: 2.3774\n",
      "11/16 19:30:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 480/1563]  lr: 1.0000e-03  eta: 0:06:59  time: 0.0565  data_time: 0.0155  memory: 583  loss: 2.2470\n",
      "11/16 19:31:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 490/1563]  lr: 1.0000e-03  eta: 0:06:58  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.2287\n",
      "11/16 19:31:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 500/1563]  lr: 1.0000e-03  eta: 0:06:57  time: 0.0570  data_time: 0.0156  memory: 583  loss: 2.2841\n",
      "11/16 19:31:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 510/1563]  lr: 1.0000e-03  eta: 0:06:57  time: 0.0568  data_time: 0.0157  memory: 583  loss: 2.2093\n",
      "11/16 19:31:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 520/1563]  lr: 1.0000e-03  eta: 0:06:56  time: 0.0570  data_time: 0.0157  memory: 583  loss: 2.3259\n",
      "11/16 19:31:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 530/1563]  lr: 1.0000e-03  eta: 0:06:56  time: 0.0572  data_time: 0.0157  memory: 583  loss: 2.1771\n",
      "11/16 19:31:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 540/1563]  lr: 1.0000e-03  eta: 0:06:55  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.2184\n",
      "11/16 19:31:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 550/1563]  lr: 1.0000e-03  eta: 0:06:54  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.1943\n",
      "11/16 19:31:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 560/1563]  lr: 1.0000e-03  eta: 0:06:54  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.2307\n",
      "11/16 19:31:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 570/1563]  lr: 1.0000e-03  eta: 0:06:53  time: 0.0570  data_time: 0.0156  memory: 583  loss: 2.1997\n",
      "11/16 19:31:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 580/1563]  lr: 1.0000e-03  eta: 0:06:53  time: 0.0575  data_time: 0.0158  memory: 583  loss: 2.3196\n",
      "11/16 19:31:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 590/1563]  lr: 1.0000e-03  eta: 0:06:52  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.4100\n",
      "11/16 19:31:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 600/1563]  lr: 1.0000e-03  eta: 0:06:51  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.3546\n",
      "11/16 19:31:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 610/1563]  lr: 1.0000e-03  eta: 0:06:51  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.2251\n",
      "11/16 19:31:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 620/1563]  lr: 1.0000e-03  eta: 0:06:50  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.1233\n",
      "11/16 19:31:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 630/1563]  lr: 1.0000e-03  eta: 0:06:50  time: 0.0567  data_time: 0.0155  memory: 583  loss: 2.3149\n",
      "11/16 19:31:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 640/1563]  lr: 1.0000e-03  eta: 0:06:49  time: 0.0567  data_time: 0.0155  memory: 583  loss: 2.0781\n",
      "11/16 19:31:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 650/1563]  lr: 1.0000e-03  eta: 0:06:48  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.5079\n",
      "11/16 19:31:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 660/1563]  lr: 1.0000e-03  eta: 0:06:48  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.4047\n",
      "11/16 19:31:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 670/1563]  lr: 1.0000e-03  eta: 0:06:47  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.2861\n",
      "11/16 19:31:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 680/1563]  lr: 1.0000e-03  eta: 0:06:47  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.3053\n",
      "11/16 19:31:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 690/1563]  lr: 1.0000e-03  eta: 0:06:46  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.2480\n",
      "11/16 19:31:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 700/1563]  lr: 1.0000e-03  eta: 0:06:45  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.1948\n",
      "11/16 19:31:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 710/1563]  lr: 1.0000e-03  eta: 0:06:45  time: 0.0566  data_time: 0.0155  memory: 583  loss: 2.3047\n",
      "11/16 19:31:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 720/1563]  lr: 1.0000e-03  eta: 0:06:44  time: 0.0567  data_time: 0.0156  memory: 583  loss: 2.2473\n",
      "11/16 19:31:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 730/1563]  lr: 1.0000e-03  eta: 0:06:44  time: 0.0569  data_time: 0.0155  memory: 583  loss: 2.2633\n",
      "11/16 19:31:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 740/1563]  lr: 1.0000e-03  eta: 0:06:43  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.1047\n",
      "11/16 19:31:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 750/1563]  lr: 1.0000e-03  eta: 0:06:42  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.3204\n",
      "11/16 19:31:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 760/1563]  lr: 1.0000e-03  eta: 0:06:42  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.2244\n",
      "11/16 19:31:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 770/1563]  lr: 1.0000e-03  eta: 0:06:41  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.1751\n",
      "11/16 19:31:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 780/1563]  lr: 1.0000e-03  eta: 0:06:41  time: 0.0567  data_time: 0.0155  memory: 583  loss: 2.3935\n",
      "11/16 19:31:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 790/1563]  lr: 1.0000e-03  eta: 0:06:40  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.1178\n",
      "11/16 19:31:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 800/1563]  lr: 1.0000e-03  eta: 0:06:40  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.2400\n",
      "11/16 19:31:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 810/1563]  lr: 1.0000e-03  eta: 0:06:39  time: 0.0568  data_time: 0.0155  memory: 583  loss: 2.2427\n",
      "11/16 19:31:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 820/1563]  lr: 1.0000e-03  eta: 0:06:38  time: 0.0567  data_time: 0.0155  memory: 583  loss: 2.1875\n",
      "11/16 19:31:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 830/1563]  lr: 1.0000e-03  eta: 0:06:38  time: 0.0567  data_time: 0.0156  memory: 583  loss: 2.1405\n",
      "11/16 19:31:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 840/1563]  lr: 1.0000e-03  eta: 0:06:37  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.1878\n",
      "11/16 19:31:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 850/1563]  lr: 1.0000e-03  eta: 0:06:37  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.0904\n",
      "11/16 19:31:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 860/1563]  lr: 1.0000e-03  eta: 0:06:36  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.1568\n",
      "11/16 19:31:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 870/1563]  lr: 1.0000e-03  eta: 0:06:35  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.0799\n",
      "11/16 19:31:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 880/1563]  lr: 1.0000e-03  eta: 0:06:35  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.1147\n",
      "11/16 19:31:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 890/1563]  lr: 1.0000e-03  eta: 0:06:34  time: 0.0567  data_time: 0.0156  memory: 583  loss: 1.9687\n",
      "11/16 19:31:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 900/1563]  lr: 1.0000e-03  eta: 0:06:34  time: 0.0570  data_time: 0.0156  memory: 583  loss: 2.1428\n",
      "11/16 19:31:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 910/1563]  lr: 1.0000e-03  eta: 0:06:33  time: 0.0569  data_time: 0.0157  memory: 583  loss: 2.1266\n",
      "11/16 19:31:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 920/1563]  lr: 1.0000e-03  eta: 0:06:32  time: 0.0567  data_time: 0.0156  memory: 583  loss: 2.1522\n",
      "11/16 19:31:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 930/1563]  lr: 1.0000e-03  eta: 0:06:32  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.0761\n",
      "11/16 19:31:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 940/1563]  lr: 1.0000e-03  eta: 0:06:31  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.1860\n",
      "11/16 19:31:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 950/1563]  lr: 1.0000e-03  eta: 0:06:31  time: 0.0570  data_time: 0.0156  memory: 583  loss: 2.0426\n",
      "11/16 19:31:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 960/1563]  lr: 1.0000e-03  eta: 0:06:30  time: 0.0570  data_time: 0.0157  memory: 583  loss: 2.2578\n",
      "11/16 19:31:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 970/1563]  lr: 1.0000e-03  eta: 0:06:30  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.1935\n",
      "11/16 19:31:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 980/1563]  lr: 1.0000e-03  eta: 0:06:29  time: 0.0569  data_time: 0.0156  memory: 583  loss: 1.9832\n",
      "11/16 19:31:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 990/1563]  lr: 1.0000e-03  eta: 0:06:28  time: 0.0567  data_time: 0.0155  memory: 583  loss: 2.1283\n",
      "11/16 19:31:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:31:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1000/1563]  lr: 1.0000e-03  eta: 0:06:28  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.1035\n",
      "11/16 19:31:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1010/1563]  lr: 1.0000e-03  eta: 0:06:27  time: 0.0577  data_time: 0.0161  memory: 583  loss: 2.0732\n",
      "11/16 19:31:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1020/1563]  lr: 1.0000e-03  eta: 0:06:27  time: 0.0569  data_time: 0.0156  memory: 583  loss: 1.9369\n",
      "11/16 19:31:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1030/1563]  lr: 1.0000e-03  eta: 0:06:26  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.0293\n",
      "11/16 19:31:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1040/1563]  lr: 1.0000e-03  eta: 0:06:26  time: 0.0572  data_time: 0.0156  memory: 583  loss: 2.0615\n",
      "11/16 19:31:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1050/1563]  lr: 1.0000e-03  eta: 0:06:25  time: 0.0569  data_time: 0.0157  memory: 583  loss: 2.1302\n",
      "11/16 19:31:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1060/1563]  lr: 1.0000e-03  eta: 0:06:24  time: 0.0569  data_time: 0.0155  memory: 583  loss: 2.1177\n",
      "11/16 19:31:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1070/1563]  lr: 1.0000e-03  eta: 0:06:24  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.1026\n",
      "11/16 19:31:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1080/1563]  lr: 1.0000e-03  eta: 0:06:23  time: 0.0569  data_time: 0.0155  memory: 583  loss: 2.0996\n",
      "11/16 19:31:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1090/1563]  lr: 1.0000e-03  eta: 0:06:23  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.0525\n",
      "11/16 19:31:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1100/1563]  lr: 1.0000e-03  eta: 0:06:22  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.0588\n",
      "11/16 19:31:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1110/1563]  lr: 1.0000e-03  eta: 0:06:22  time: 0.0570  data_time: 0.0156  memory: 583  loss: 1.9882\n",
      "11/16 19:31:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1120/1563]  lr: 1.0000e-03  eta: 0:06:21  time: 0.0573  data_time: 0.0159  memory: 583  loss: 2.0403\n",
      "11/16 19:31:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1130/1563]  lr: 1.0000e-03  eta: 0:06:20  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.0466\n",
      "11/16 19:31:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1140/1563]  lr: 1.0000e-03  eta: 0:06:20  time: 0.0572  data_time: 0.0157  memory: 583  loss: 1.9862\n",
      "11/16 19:31:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1150/1563]  lr: 1.0000e-03  eta: 0:06:19  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.0484\n",
      "11/16 19:31:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1160/1563]  lr: 1.0000e-03  eta: 0:06:19  time: 0.0569  data_time: 0.0156  memory: 583  loss: 1.9743\n",
      "11/16 19:31:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1170/1563]  lr: 1.0000e-03  eta: 0:06:18  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.0298\n",
      "11/16 19:31:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1180/1563]  lr: 1.0000e-03  eta: 0:06:18  time: 0.0571  data_time: 0.0156  memory: 583  loss: 2.0166\n",
      "11/16 19:31:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1190/1563]  lr: 1.0000e-03  eta: 0:06:17  time: 0.0568  data_time: 0.0156  memory: 583  loss: 1.8625\n",
      "11/16 19:31:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1200/1563]  lr: 1.0000e-03  eta: 0:06:16  time: 0.0573  data_time: 0.0159  memory: 583  loss: 1.9544\n",
      "11/16 19:31:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1210/1563]  lr: 1.0000e-03  eta: 0:06:16  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.0050\n",
      "11/16 19:31:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1220/1563]  lr: 1.0000e-03  eta: 0:06:15  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.0514\n",
      "11/16 19:31:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1230/1563]  lr: 1.0000e-03  eta: 0:06:15  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.0199\n",
      "11/16 19:31:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1240/1563]  lr: 1.0000e-03  eta: 0:06:14  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.0691\n",
      "11/16 19:31:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1250/1563]  lr: 1.0000e-03  eta: 0:06:14  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.0770\n",
      "11/16 19:31:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1260/1563]  lr: 1.0000e-03  eta: 0:06:13  time: 0.0567  data_time: 0.0156  memory: 583  loss: 2.0407\n",
      "11/16 19:31:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1270/1563]  lr: 1.0000e-03  eta: 0:06:12  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.0224\n",
      "11/16 19:31:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1280/1563]  lr: 1.0000e-03  eta: 0:06:12  time: 0.0569  data_time: 0.0156  memory: 583  loss: 2.0722\n",
      "11/16 19:31:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1290/1563]  lr: 1.0000e-03  eta: 0:06:11  time: 0.0569  data_time: 0.0156  memory: 583  loss: 1.9250\n",
      "11/16 19:31:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1300/1563]  lr: 1.0000e-03  eta: 0:06:11  time: 0.0567  data_time: 0.0156  memory: 583  loss: 1.9272\n",
      "11/16 19:31:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1310/1563]  lr: 1.0000e-03  eta: 0:06:10  time: 0.0568  data_time: 0.0156  memory: 583  loss: 2.1550\n",
      "11/16 19:31:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1320/1563]  lr: 1.0000e-03  eta: 0:06:10  time: 0.0572  data_time: 0.0157  memory: 583  loss: 1.9615\n",
      "11/16 19:31:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1330/1563]  lr: 1.0000e-03  eta: 0:06:09  time: 0.0568  data_time: 0.0157  memory: 583  loss: 2.0335\n",
      "11/16 19:31:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1340/1563]  lr: 1.0000e-03  eta: 0:06:08  time: 0.0574  data_time: 0.0157  memory: 583  loss: 2.0045\n",
      "11/16 19:31:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1350/1563]  lr: 1.0000e-03  eta: 0:06:08  time: 0.0567  data_time: 0.0156  memory: 583  loss: 1.9513\n",
      "11/16 19:31:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1360/1563]  lr: 1.0000e-03  eta: 0:06:07  time: 0.0568  data_time: 0.0155  memory: 583  loss: 2.0505\n",
      "11/16 19:31:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1370/1563]  lr: 1.0000e-03  eta: 0:06:07  time: 0.0567  data_time: 0.0156  memory: 583  loss: 1.9027\n",
      "11/16 19:31:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1380/1563]  lr: 1.0000e-03  eta: 0:06:06  time: 0.0567  data_time: 0.0156  memory: 583  loss: 1.8259\n",
      "11/16 19:31:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1390/1563]  lr: 1.0000e-03  eta: 0:06:06  time: 0.0572  data_time: 0.0156  memory: 583  loss: 2.0147\n",
      "11/16 19:31:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1400/1563]  lr: 1.0000e-03  eta: 0:06:05  time: 0.0576  data_time: 0.0157  memory: 583  loss: 2.1101\n",
      "11/16 19:31:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1410/1563]  lr: 1.0000e-03  eta: 0:06:04  time: 0.0576  data_time: 0.0157  memory: 583  loss: 1.8542\n",
      "11/16 19:31:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1420/1563]  lr: 1.0000e-03  eta: 0:06:04  time: 0.0570  data_time: 0.0156  memory: 583  loss: 1.7707\n",
      "11/16 19:31:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1430/1563]  lr: 1.0000e-03  eta: 0:06:03  time: 0.0568  data_time: 0.0156  memory: 583  loss: 1.9122\n",
      "11/16 19:31:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1440/1563]  lr: 1.0000e-03  eta: 0:06:03  time: 0.0566  data_time: 0.0155  memory: 583  loss: 1.9640\n",
      "11/16 19:31:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1450/1563]  lr: 1.0000e-03  eta: 0:06:02  time: 0.0568  data_time: 0.0156  memory: 583  loss: 1.9841\n",
      "11/16 19:31:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1460/1563]  lr: 1.0000e-03  eta: 0:06:02  time: 0.0571  data_time: 0.0156  memory: 583  loss: 1.9097\n",
      "11/16 19:31:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1470/1563]  lr: 1.0000e-03  eta: 0:06:01  time: 0.0569  data_time: 0.0157  memory: 583  loss: 1.8479\n",
      "11/16 19:31:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1480/1563]  lr: 1.0000e-03  eta: 0:06:00  time: 0.0576  data_time: 0.0159  memory: 583  loss: 1.9360\n",
      "11/16 19:31:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1490/1563]  lr: 1.0000e-03  eta: 0:06:00  time: 0.0575  data_time: 0.0157  memory: 583  loss: 1.9871\n",
      "11/16 19:31:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1500/1563]  lr: 1.0000e-03  eta: 0:05:59  time: 0.0570  data_time: 0.0156  memory: 583  loss: 1.9939\n",
      "11/16 19:31:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1510/1563]  lr: 1.0000e-03  eta: 0:05:59  time: 0.0567  data_time: 0.0155  memory: 583  loss: 2.0558\n",
      "11/16 19:31:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1520/1563]  lr: 1.0000e-03  eta: 0:05:58  time: 0.0567  data_time: 0.0156  memory: 583  loss: 1.9977\n",
      "11/16 19:31:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1530/1563]  lr: 1.0000e-03  eta: 0:05:58  time: 0.0569  data_time: 0.0156  memory: 583  loss: 1.9616\n",
      "11/16 19:31:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1540/1563]  lr: 1.0000e-03  eta: 0:05:57  time: 0.0569  data_time: 0.0156  memory: 583  loss: 1.9128\n",
      "11/16 19:32:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1550/1563]  lr: 1.0000e-03  eta: 0:05:56  time: 0.0568  data_time: 0.0156  memory: 583  loss: 1.9564\n",
      "11/16 19:32:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1560/1563]  lr: 1.0000e-03  eta: 0:05:56  time: 0.0567  data_time: 0.0156  memory: 583  loss: 2.1554\n",
      "11/16 19:32:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:32:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Saving checkpoint at 1 epochs\n",
      "11/16 19:32:01 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - `save_param_scheduler` is True but `self.param_schedulers` is None, so skip saving parameter schedulers\n",
      "11/16 19:32:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 10/313]    eta: 0:00:23  time: 0.0761  data_time: 0.0110  memory: 583  \n",
      "11/16 19:32:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 20/313]    eta: 0:00:14  time: 0.0195  data_time: 0.0097  memory: 424  \n",
      "11/16 19:32:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 30/313]    eta: 0:00:10  time: 0.0194  data_time: 0.0096  memory: 424  \n",
      "11/16 19:32:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 40/313]    eta: 0:00:08  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:32:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 50/313]    eta: 0:00:07  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 60/313]    eta: 0:00:06  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 70/313]    eta: 0:00:06  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 80/313]    eta: 0:00:05  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:32:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 90/313]    eta: 0:00:05  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][100/313]    eta: 0:00:04  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][110/313]    eta: 0:00:04  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][120/313]    eta: 0:00:04  time: 0.0165  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][130/313]    eta: 0:00:03  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][140/313]    eta: 0:00:03  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:32:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][150/313]    eta: 0:00:03  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][160/313]    eta: 0:00:03  time: 0.0165  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][170/313]    eta: 0:00:02  time: 0.0169  data_time: 0.0084  memory: 424  \n",
      "11/16 19:32:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][180/313]    eta: 0:00:02  time: 0.0170  data_time: 0.0085  memory: 424  \n",
      "11/16 19:32:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][190/313]    eta: 0:00:02  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:32:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][200/313]    eta: 0:00:02  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:32:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][210/313]    eta: 0:00:02  time: 0.0165  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][220/313]    eta: 0:00:01  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][230/313]    eta: 0:00:01  time: 0.0165  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][240/313]    eta: 0:00:01  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][250/313]    eta: 0:00:01  time: 0.0169  data_time: 0.0085  memory: 424  \n",
      "11/16 19:32:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][260/313]    eta: 0:00:01  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][270/313]    eta: 0:00:00  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][280/313]    eta: 0:00:00  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][290/313]    eta: 0:00:00  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][300/313]    eta: 0:00:00  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][310/313]    eta: 0:00:00  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:32:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][313/313]    accuracy: 35.3700  data_time: 0.0085  time: 0.0187\n",
      "11/16 19:32:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  10/1563]  lr: 1.0000e-03  eta: 0:05:55  time: 0.0514  data_time: 0.0131  memory: 583  loss: 1.8511\n",
      "11/16 19:32:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  20/1563]  lr: 1.0000e-03  eta: 0:05:54  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.9076\n",
      "11/16 19:32:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  30/1563]  lr: 1.0000e-03  eta: 0:05:53  time: 0.0515  data_time: 0.0132  memory: 583  loss: 1.9955\n",
      "11/16 19:32:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  40/1563]  lr: 1.0000e-03  eta: 0:05:53  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.8968\n",
      "11/16 19:32:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  50/1563]  lr: 1.0000e-03  eta: 0:05:52  time: 0.0509  data_time: 0.0132  memory: 583  loss: 2.0139\n",
      "11/16 19:32:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  60/1563]  lr: 1.0000e-03  eta: 0:05:51  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.9494\n",
      "11/16 19:32:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  70/1563]  lr: 1.0000e-03  eta: 0:05:50  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.9847\n",
      "11/16 19:32:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  80/1563]  lr: 1.0000e-03  eta: 0:05:50  time: 0.0520  data_time: 0.0135  memory: 583  loss: 2.0855\n",
      "11/16 19:32:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  90/1563]  lr: 1.0000e-03  eta: 0:05:49  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.9568\n",
      "11/16 19:32:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 100/1563]  lr: 1.0000e-03  eta: 0:05:48  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.9868\n",
      "11/16 19:32:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 110/1563]  lr: 1.0000e-03  eta: 0:05:47  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.9593\n",
      "11/16 19:32:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 120/1563]  lr: 1.0000e-03  eta: 0:05:47  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.7831\n",
      "11/16 19:32:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 130/1563]  lr: 1.0000e-03  eta: 0:05:46  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.9188\n",
      "11/16 19:32:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 140/1563]  lr: 1.0000e-03  eta: 0:05:45  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.8471\n",
      "11/16 19:32:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 150/1563]  lr: 1.0000e-03  eta: 0:05:44  time: 0.0521  data_time: 0.0137  memory: 583  loss: 1.8796\n",
      "11/16 19:32:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 160/1563]  lr: 1.0000e-03  eta: 0:05:44  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.8865\n",
      "11/16 19:32:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 170/1563]  lr: 1.0000e-03  eta: 0:05:43  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.8872\n",
      "11/16 19:32:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 180/1563]  lr: 1.0000e-03  eta: 0:05:42  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.9043\n",
      "11/16 19:32:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 190/1563]  lr: 1.0000e-03  eta: 0:05:41  time: 0.0512  data_time: 0.0134  memory: 583  loss: 2.0034\n",
      "11/16 19:32:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 200/1563]  lr: 1.0000e-03  eta: 0:05:41  time: 0.0513  data_time: 0.0133  memory: 583  loss: 1.8433\n",
      "11/16 19:32:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 210/1563]  lr: 1.0000e-03  eta: 0:05:40  time: 0.0522  data_time: 0.0135  memory: 583  loss: 2.0625\n",
      "11/16 19:32:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 220/1563]  lr: 1.0000e-03  eta: 0:05:39  time: 0.0520  data_time: 0.0134  memory: 583  loss: 2.0319\n",
      "11/16 19:32:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 230/1563]  lr: 1.0000e-03  eta: 0:05:39  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.8396\n",
      "11/16 19:32:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 240/1563]  lr: 1.0000e-03  eta: 0:05:38  time: 0.0519  data_time: 0.0132  memory: 583  loss: 1.9666\n",
      "11/16 19:32:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 250/1563]  lr: 1.0000e-03  eta: 0:05:37  time: 0.0519  data_time: 0.0135  memory: 583  loss: 1.8276\n",
      "11/16 19:32:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 260/1563]  lr: 1.0000e-03  eta: 0:05:36  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.8790\n",
      "11/16 19:32:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 270/1563]  lr: 1.0000e-03  eta: 0:05:36  time: 0.0515  data_time: 0.0132  memory: 583  loss: 1.7974\n",
      "11/16 19:32:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 280/1563]  lr: 1.0000e-03  eta: 0:05:35  time: 0.0514  data_time: 0.0132  memory: 583  loss: 1.8357\n",
      "11/16 19:32:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 290/1563]  lr: 1.0000e-03  eta: 0:05:34  time: 0.0515  data_time: 0.0131  memory: 583  loss: 1.8770\n",
      "11/16 19:32:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 300/1563]  lr: 1.0000e-03  eta: 0:05:34  time: 0.0515  data_time: 0.0132  memory: 583  loss: 1.9502\n",
      "11/16 19:32:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 310/1563]  lr: 1.0000e-03  eta: 0:05:33  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.9055\n",
      "11/16 19:32:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 320/1563]  lr: 1.0000e-03  eta: 0:05:32  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.9013\n",
      "11/16 19:32:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 330/1563]  lr: 1.0000e-03  eta: 0:05:32  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.8961\n",
      "11/16 19:32:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 340/1563]  lr: 1.0000e-03  eta: 0:05:31  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.9397\n",
      "11/16 19:32:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 350/1563]  lr: 1.0000e-03  eta: 0:05:30  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.9173\n",
      "11/16 19:32:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 360/1563]  lr: 1.0000e-03  eta: 0:05:29  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.8247\n",
      "11/16 19:32:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 370/1563]  lr: 1.0000e-03  eta: 0:05:29  time: 0.0518  data_time: 0.0132  memory: 583  loss: 1.8350\n",
      "11/16 19:32:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 380/1563]  lr: 1.0000e-03  eta: 0:05:28  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.8715\n",
      "11/16 19:32:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 390/1563]  lr: 1.0000e-03  eta: 0:05:27  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.7986\n",
      "11/16 19:32:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 400/1563]  lr: 1.0000e-03  eta: 0:05:27  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.9252\n",
      "11/16 19:32:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 410/1563]  lr: 1.0000e-03  eta: 0:05:26  time: 0.0523  data_time: 0.0134  memory: 583  loss: 1.8617\n",
      "11/16 19:32:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 420/1563]  lr: 1.0000e-03  eta: 0:05:25  time: 0.0523  data_time: 0.0136  memory: 583  loss: 1.8652\n",
      "11/16 19:32:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 430/1563]  lr: 1.0000e-03  eta: 0:05:25  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.8999\n",
      "11/16 19:32:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:32:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 440/1563]  lr: 1.0000e-03  eta: 0:05:24  time: 0.0525  data_time: 0.0137  memory: 583  loss: 1.7591\n",
      "11/16 19:32:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 450/1563]  lr: 1.0000e-03  eta: 0:05:23  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.8833\n",
      "11/16 19:32:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 460/1563]  lr: 1.0000e-03  eta: 0:05:23  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.7220\n",
      "11/16 19:32:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 470/1563]  lr: 1.0000e-03  eta: 0:05:22  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.9039\n",
      "11/16 19:32:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 480/1563]  lr: 1.0000e-03  eta: 0:05:21  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.8110\n",
      "11/16 19:32:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 490/1563]  lr: 1.0000e-03  eta: 0:05:21  time: 0.0521  data_time: 0.0133  memory: 583  loss: 1.7856\n",
      "11/16 19:32:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 500/1563]  lr: 1.0000e-03  eta: 0:05:20  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.8020\n",
      "11/16 19:32:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 510/1563]  lr: 1.0000e-03  eta: 0:05:19  time: 0.0516  data_time: 0.0133  memory: 583  loss: 1.8469\n",
      "11/16 19:32:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 520/1563]  lr: 1.0000e-03  eta: 0:05:19  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.8006\n",
      "11/16 19:32:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 530/1563]  lr: 1.0000e-03  eta: 0:05:18  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.7958\n",
      "11/16 19:32:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 540/1563]  lr: 1.0000e-03  eta: 0:05:17  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.7669\n",
      "11/16 19:32:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 550/1563]  lr: 1.0000e-03  eta: 0:05:17  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.8769\n",
      "11/16 19:32:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 560/1563]  lr: 1.0000e-03  eta: 0:05:16  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.7606\n",
      "11/16 19:32:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 570/1563]  lr: 1.0000e-03  eta: 0:05:15  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.8220\n",
      "11/16 19:32:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 580/1563]  lr: 1.0000e-03  eta: 0:05:15  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7862\n",
      "11/16 19:32:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 590/1563]  lr: 1.0000e-03  eta: 0:05:14  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.8417\n",
      "11/16 19:32:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 600/1563]  lr: 1.0000e-03  eta: 0:05:13  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.9000\n",
      "11/16 19:32:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 610/1563]  lr: 1.0000e-03  eta: 0:05:13  time: 0.0527  data_time: 0.0138  memory: 583  loss: 1.7480\n",
      "11/16 19:32:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 620/1563]  lr: 1.0000e-03  eta: 0:05:12  time: 0.0519  data_time: 0.0135  memory: 583  loss: 1.8431\n",
      "11/16 19:32:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 630/1563]  lr: 1.0000e-03  eta: 0:05:12  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.8513\n",
      "11/16 19:32:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 640/1563]  lr: 1.0000e-03  eta: 0:05:11  time: 0.0521  data_time: 0.0133  memory: 583  loss: 1.8626\n",
      "11/16 19:32:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 650/1563]  lr: 1.0000e-03  eta: 0:05:10  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.7403\n",
      "11/16 19:32:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 660/1563]  lr: 1.0000e-03  eta: 0:05:10  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6988\n",
      "11/16 19:32:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 670/1563]  lr: 1.0000e-03  eta: 0:05:09  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.8228\n",
      "11/16 19:32:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 680/1563]  lr: 1.0000e-03  eta: 0:05:08  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.8248\n",
      "11/16 19:32:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 690/1563]  lr: 1.0000e-03  eta: 0:05:08  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.8048\n",
      "11/16 19:32:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 700/1563]  lr: 1.0000e-03  eta: 0:05:07  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.7265\n",
      "11/16 19:32:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 710/1563]  lr: 1.0000e-03  eta: 0:05:06  time: 0.0523  data_time: 0.0133  memory: 583  loss: 1.9501\n",
      "11/16 19:32:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 720/1563]  lr: 1.0000e-03  eta: 0:05:06  time: 0.0502  data_time: 0.0134  memory: 583  loss: 1.8235\n",
      "11/16 19:32:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 730/1563]  lr: 1.0000e-03  eta: 0:05:05  time: 0.0514  data_time: 0.0132  memory: 583  loss: 1.6962\n",
      "11/16 19:32:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 740/1563]  lr: 1.0000e-03  eta: 0:05:04  time: 0.0510  data_time: 0.0134  memory: 583  loss: 1.7234\n",
      "11/16 19:32:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 750/1563]  lr: 1.0000e-03  eta: 0:05:04  time: 0.0519  data_time: 0.0135  memory: 583  loss: 1.8508\n",
      "11/16 19:32:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 760/1563]  lr: 1.0000e-03  eta: 0:05:03  time: 0.0514  data_time: 0.0132  memory: 583  loss: 1.8899\n",
      "11/16 19:32:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 770/1563]  lr: 1.0000e-03  eta: 0:05:02  time: 0.0516  data_time: 0.0133  memory: 583  loss: 1.8178\n",
      "11/16 19:32:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 780/1563]  lr: 1.0000e-03  eta: 0:05:02  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.5996\n",
      "11/16 19:32:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 790/1563]  lr: 1.0000e-03  eta: 0:05:01  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.8101\n",
      "11/16 19:32:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 800/1563]  lr: 1.0000e-03  eta: 0:05:01  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7247\n",
      "11/16 19:32:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 810/1563]  lr: 1.0000e-03  eta: 0:05:00  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.7869\n",
      "11/16 19:32:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 820/1563]  lr: 1.0000e-03  eta: 0:04:59  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7606\n",
      "11/16 19:32:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 830/1563]  lr: 1.0000e-03  eta: 0:04:59  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.9957\n",
      "11/16 19:32:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 840/1563]  lr: 1.0000e-03  eta: 0:04:58  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.7821\n",
      "11/16 19:32:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 850/1563]  lr: 1.0000e-03  eta: 0:04:57  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.8700\n",
      "11/16 19:32:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 860/1563]  lr: 1.0000e-03  eta: 0:04:57  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7949\n",
      "11/16 19:32:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 870/1563]  lr: 1.0000e-03  eta: 0:04:56  time: 0.0517  data_time: 0.0134  memory: 583  loss: 1.7867\n",
      "11/16 19:32:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 880/1563]  lr: 1.0000e-03  eta: 0:04:56  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.8850\n",
      "11/16 19:32:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 890/1563]  lr: 1.0000e-03  eta: 0:04:55  time: 0.0516  data_time: 0.0134  memory: 583  loss: 1.8644\n",
      "11/16 19:32:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 900/1563]  lr: 1.0000e-03  eta: 0:04:54  time: 0.0514  data_time: 0.0132  memory: 583  loss: 1.8152\n",
      "11/16 19:32:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 910/1563]  lr: 1.0000e-03  eta: 0:04:54  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.8192\n",
      "11/16 19:32:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 920/1563]  lr: 1.0000e-03  eta: 0:04:53  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.6881\n",
      "11/16 19:32:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 930/1563]  lr: 1.0000e-03  eta: 0:04:52  time: 0.0514  data_time: 0.0136  memory: 583  loss: 1.7314\n",
      "11/16 19:32:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 940/1563]  lr: 1.0000e-03  eta: 0:04:52  time: 0.0514  data_time: 0.0134  memory: 583  loss: 1.7789\n",
      "11/16 19:32:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 950/1563]  lr: 1.0000e-03  eta: 0:04:51  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.8036\n",
      "11/16 19:32:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 960/1563]  lr: 1.0000e-03  eta: 0:04:51  time: 0.0509  data_time: 0.0133  memory: 583  loss: 1.8447\n",
      "11/16 19:32:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 970/1563]  lr: 1.0000e-03  eta: 0:04:50  time: 0.0515  data_time: 0.0133  memory: 583  loss: 1.8573\n",
      "11/16 19:32:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 980/1563]  lr: 1.0000e-03  eta: 0:04:49  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7953\n",
      "11/16 19:32:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 990/1563]  lr: 1.0000e-03  eta: 0:04:49  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.6438\n",
      "11/16 19:32:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1000/1563]  lr: 1.0000e-03  eta: 0:04:48  time: 0.0518  data_time: 0.0132  memory: 583  loss: 1.8462\n",
      "11/16 19:33:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1010/1563]  lr: 1.0000e-03  eta: 0:04:47  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.7599\n",
      "11/16 19:33:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1020/1563]  lr: 1.0000e-03  eta: 0:04:47  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.7938\n",
      "11/16 19:33:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1030/1563]  lr: 1.0000e-03  eta: 0:04:46  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.8831\n",
      "11/16 19:33:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1040/1563]  lr: 1.0000e-03  eta: 0:04:46  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.7699\n",
      "11/16 19:33:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1050/1563]  lr: 1.0000e-03  eta: 0:04:45  time: 0.0511  data_time: 0.0133  memory: 583  loss: 1.7876\n",
      "11/16 19:33:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1060/1563]  lr: 1.0000e-03  eta: 0:04:44  time: 0.0501  data_time: 0.0133  memory: 583  loss: 1.8230\n",
      "11/16 19:33:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1070/1563]  lr: 1.0000e-03  eta: 0:04:44  time: 0.0499  data_time: 0.0132  memory: 583  loss: 1.8396\n",
      "11/16 19:33:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1080/1563]  lr: 1.0000e-03  eta: 0:04:43  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.7037\n",
      "11/16 19:33:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1090/1563]  lr: 1.0000e-03  eta: 0:04:43  time: 0.0520  data_time: 0.0136  memory: 583  loss: 1.6823\n",
      "11/16 19:33:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1100/1563]  lr: 1.0000e-03  eta: 0:04:42  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.8701\n",
      "11/16 19:33:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1110/1563]  lr: 1.0000e-03  eta: 0:04:41  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.8504\n",
      "11/16 19:33:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1120/1563]  lr: 1.0000e-03  eta: 0:04:41  time: 0.0519  data_time: 0.0135  memory: 583  loss: 1.8349\n",
      "11/16 19:33:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1130/1563]  lr: 1.0000e-03  eta: 0:04:40  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.7067\n",
      "11/16 19:33:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1140/1563]  lr: 1.0000e-03  eta: 0:04:39  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.8023\n",
      "11/16 19:33:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1150/1563]  lr: 1.0000e-03  eta: 0:04:39  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.6927\n",
      "11/16 19:33:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1160/1563]  lr: 1.0000e-03  eta: 0:04:38  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6391\n",
      "11/16 19:33:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1170/1563]  lr: 1.0000e-03  eta: 0:04:38  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.7171\n",
      "11/16 19:33:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1180/1563]  lr: 1.0000e-03  eta: 0:04:37  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.7668\n",
      "11/16 19:33:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1190/1563]  lr: 1.0000e-03  eta: 0:04:36  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7758\n",
      "11/16 19:33:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1200/1563]  lr: 1.0000e-03  eta: 0:04:36  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.7493\n",
      "11/16 19:33:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1210/1563]  lr: 1.0000e-03  eta: 0:04:35  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.7973\n",
      "11/16 19:33:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1220/1563]  lr: 1.0000e-03  eta: 0:04:35  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.8105\n",
      "11/16 19:33:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1230/1563]  lr: 1.0000e-03  eta: 0:04:34  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.8216\n",
      "11/16 19:33:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1240/1563]  lr: 1.0000e-03  eta: 0:04:33  time: 0.0508  data_time: 0.0132  memory: 583  loss: 1.8057\n",
      "11/16 19:33:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1250/1563]  lr: 1.0000e-03  eta: 0:04:33  time: 0.0514  data_time: 0.0132  memory: 583  loss: 1.7161\n",
      "11/16 19:33:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1260/1563]  lr: 1.0000e-03  eta: 0:04:32  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7758\n",
      "11/16 19:33:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1270/1563]  lr: 1.0000e-03  eta: 0:04:32  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.7466\n",
      "11/16 19:33:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1280/1563]  lr: 1.0000e-03  eta: 0:04:31  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.7950\n",
      "11/16 19:33:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1290/1563]  lr: 1.0000e-03  eta: 0:04:30  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.8379\n",
      "11/16 19:33:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1300/1563]  lr: 1.0000e-03  eta: 0:04:30  time: 0.0516  data_time: 0.0133  memory: 583  loss: 1.7630\n",
      "11/16 19:33:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1310/1563]  lr: 1.0000e-03  eta: 0:04:29  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.7248\n",
      "11/16 19:33:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1320/1563]  lr: 1.0000e-03  eta: 0:04:29  time: 0.0513  data_time: 0.0132  memory: 583  loss: 1.6909\n",
      "11/16 19:33:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1330/1563]  lr: 1.0000e-03  eta: 0:04:28  time: 0.0516  data_time: 0.0133  memory: 583  loss: 1.7019\n",
      "11/16 19:33:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1340/1563]  lr: 1.0000e-03  eta: 0:04:27  time: 0.0517  data_time: 0.0134  memory: 583  loss: 1.8237\n",
      "11/16 19:33:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1350/1563]  lr: 1.0000e-03  eta: 0:04:27  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.7761\n",
      "11/16 19:33:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1360/1563]  lr: 1.0000e-03  eta: 0:04:26  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.7088\n",
      "11/16 19:33:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1370/1563]  lr: 1.0000e-03  eta: 0:04:26  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.7784\n",
      "11/16 19:33:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1380/1563]  lr: 1.0000e-03  eta: 0:04:25  time: 0.0526  data_time: 0.0138  memory: 583  loss: 1.8132\n",
      "11/16 19:33:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1390/1563]  lr: 1.0000e-03  eta: 0:04:25  time: 0.0528  data_time: 0.0140  memory: 583  loss: 1.7568\n",
      "11/16 19:33:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1400/1563]  lr: 1.0000e-03  eta: 0:04:24  time: 0.0527  data_time: 0.0138  memory: 583  loss: 1.7457\n",
      "11/16 19:33:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1410/1563]  lr: 1.0000e-03  eta: 0:04:23  time: 0.0525  data_time: 0.0135  memory: 583  loss: 1.6736\n",
      "11/16 19:33:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1420/1563]  lr: 1.0000e-03  eta: 0:04:23  time: 0.0525  data_time: 0.0137  memory: 583  loss: 1.7935\n",
      "11/16 19:33:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1430/1563]  lr: 1.0000e-03  eta: 0:04:22  time: 0.0528  data_time: 0.0138  memory: 583  loss: 1.7187\n",
      "11/16 19:33:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:33:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1440/1563]  lr: 1.0000e-03  eta: 0:04:22  time: 0.0532  data_time: 0.0142  memory: 583  loss: 1.7448\n",
      "11/16 19:33:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1450/1563]  lr: 1.0000e-03  eta: 0:04:21  time: 0.0528  data_time: 0.0137  memory: 583  loss: 1.6961\n",
      "11/16 19:33:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1460/1563]  lr: 1.0000e-03  eta: 0:04:21  time: 0.0525  data_time: 0.0136  memory: 583  loss: 1.6872\n",
      "11/16 19:33:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1470/1563]  lr: 1.0000e-03  eta: 0:04:20  time: 0.0526  data_time: 0.0138  memory: 583  loss: 1.9040\n",
      "11/16 19:33:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1480/1563]  lr: 1.0000e-03  eta: 0:04:19  time: 0.0524  data_time: 0.0135  memory: 583  loss: 1.8377\n",
      "11/16 19:33:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1490/1563]  lr: 1.0000e-03  eta: 0:04:19  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.7021\n",
      "11/16 19:33:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1500/1563]  lr: 1.0000e-03  eta: 0:04:18  time: 0.0525  data_time: 0.0135  memory: 583  loss: 1.8644\n",
      "11/16 19:33:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1510/1563]  lr: 1.0000e-03  eta: 0:04:18  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.7350\n",
      "11/16 19:33:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1520/1563]  lr: 1.0000e-03  eta: 0:04:17  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.8119\n",
      "11/16 19:33:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1530/1563]  lr: 1.0000e-03  eta: 0:04:17  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.7103\n",
      "11/16 19:33:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1540/1563]  lr: 1.0000e-03  eta: 0:04:16  time: 0.0526  data_time: 0.0137  memory: 583  loss: 1.6662\n",
      "11/16 19:33:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1550/1563]  lr: 1.0000e-03  eta: 0:04:15  time: 0.0525  data_time: 0.0136  memory: 583  loss: 1.6727\n",
      "11/16 19:33:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1560/1563]  lr: 1.0000e-03  eta: 0:04:15  time: 0.0528  data_time: 0.0139  memory: 583  loss: 1.8069\n",
      "11/16 19:33:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:33:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Saving checkpoint at 2 epochs\n",
      "11/16 19:33:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 10/313]    eta: 0:00:05  time: 0.0182  data_time: 0.0097  memory: 583  \n",
      "11/16 19:33:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 20/313]    eta: 0:00:05  time: 0.0171  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 30/313]    eta: 0:00:04  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 40/313]    eta: 0:00:04  time: 0.0173  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 50/313]    eta: 0:00:04  time: 0.0171  data_time: 0.0085  memory: 424  \n",
      "11/16 19:33:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 60/313]    eta: 0:00:04  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 70/313]    eta: 0:00:04  time: 0.0171  data_time: 0.0085  memory: 424  \n",
      "11/16 19:33:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 80/313]    eta: 0:00:04  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 90/313]    eta: 0:00:03  time: 0.0170  data_time: 0.0084  memory: 424  \n",
      "11/16 19:33:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][100/313]    eta: 0:00:03  time: 0.0171  data_time: 0.0085  memory: 424  \n",
      "11/16 19:33:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][110/313]    eta: 0:00:03  time: 0.0171  data_time: 0.0085  memory: 424  \n",
      "11/16 19:33:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][120/313]    eta: 0:00:03  time: 0.0171  data_time: 0.0085  memory: 424  \n",
      "11/16 19:33:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][130/313]    eta: 0:00:03  time: 0.0171  data_time: 0.0085  memory: 424  \n",
      "11/16 19:33:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][140/313]    eta: 0:00:02  time: 0.0172  data_time: 0.0085  memory: 424  \n",
      "11/16 19:33:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][150/313]    eta: 0:00:02  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][160/313]    eta: 0:00:02  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][170/313]    eta: 0:00:02  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][180/313]    eta: 0:00:02  time: 0.0171  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][190/313]    eta: 0:00:02  time: 0.0171  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][200/313]    eta: 0:00:01  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][210/313]    eta: 0:00:01  time: 0.0170  data_time: 0.0085  memory: 424  \n",
      "11/16 19:33:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][220/313]    eta: 0:00:01  time: 0.0173  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][230/313]    eta: 0:00:01  time: 0.0175  data_time: 0.0087  memory: 424  \n",
      "11/16 19:33:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][240/313]    eta: 0:00:01  time: 0.0173  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][250/313]    eta: 0:00:01  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][260/313]    eta: 0:00:00  time: 0.0172  data_time: 0.0085  memory: 424  \n",
      "11/16 19:33:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][270/313]    eta: 0:00:00  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][280/313]    eta: 0:00:00  time: 0.0172  data_time: 0.0085  memory: 424  \n",
      "11/16 19:33:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][290/313]    eta: 0:00:00  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][300/313]    eta: 0:00:00  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][310/313]    eta: 0:00:00  time: 0.0172  data_time: 0.0086  memory: 424  \n",
      "11/16 19:33:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][313/313]    accuracy: 43.0100  data_time: 0.0086  time: 0.0172\n",
      "11/16 19:33:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  10/1563]  lr: 1.0000e-03  eta: 0:04:14  time: 0.0533  data_time: 0.0139  memory: 583  loss: 1.7525\n",
      "11/16 19:33:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  20/1563]  lr: 1.0000e-03  eta: 0:04:14  time: 0.0540  data_time: 0.0148  memory: 583  loss: 1.7308\n",
      "11/16 19:33:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  30/1563]  lr: 1.0000e-03  eta: 0:04:13  time: 0.0527  data_time: 0.0139  memory: 583  loss: 1.6290\n",
      "11/16 19:33:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  40/1563]  lr: 1.0000e-03  eta: 0:04:12  time: 0.0529  data_time: 0.0136  memory: 583  loss: 1.6476\n",
      "11/16 19:33:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  50/1563]  lr: 1.0000e-03  eta: 0:04:12  time: 0.0561  data_time: 0.0164  memory: 583  loss: 1.7265\n",
      "11/16 19:33:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  60/1563]  lr: 1.0000e-03  eta: 0:04:11  time: 0.0553  data_time: 0.0149  memory: 583  loss: 1.8372\n",
      "11/16 19:33:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  70/1563]  lr: 1.0000e-03  eta: 0:04:11  time: 0.0595  data_time: 0.0171  memory: 583  loss: 1.6949\n",
      "11/16 19:33:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  80/1563]  lr: 1.0000e-03  eta: 0:04:10  time: 0.0533  data_time: 0.0144  memory: 583  loss: 1.7641\n",
      "11/16 19:33:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  90/1563]  lr: 1.0000e-03  eta: 0:04:10  time: 0.0552  data_time: 0.0153  memory: 583  loss: 1.6955\n",
      "11/16 19:33:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 100/1563]  lr: 1.0000e-03  eta: 0:04:09  time: 0.0544  data_time: 0.0144  memory: 583  loss: 1.6036\n",
      "11/16 19:33:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 110/1563]  lr: 1.0000e-03  eta: 0:04:09  time: 0.0530  data_time: 0.0139  memory: 583  loss: 1.7715\n",
      "11/16 19:33:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 120/1563]  lr: 1.0000e-03  eta: 0:04:08  time: 0.0567  data_time: 0.0158  memory: 583  loss: 1.6335\n",
      "11/16 19:33:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 130/1563]  lr: 1.0000e-03  eta: 0:04:08  time: 0.0527  data_time: 0.0136  memory: 583  loss: 1.7649\n",
      "11/16 19:33:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 140/1563]  lr: 1.0000e-03  eta: 0:04:07  time: 0.0543  data_time: 0.0151  memory: 583  loss: 1.5909\n",
      "11/16 19:33:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 150/1563]  lr: 1.0000e-03  eta: 0:04:06  time: 0.0529  data_time: 0.0137  memory: 583  loss: 1.6598\n",
      "11/16 19:33:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 160/1563]  lr: 1.0000e-03  eta: 0:04:06  time: 0.0535  data_time: 0.0139  memory: 583  loss: 1.6848\n",
      "11/16 19:33:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 170/1563]  lr: 1.0000e-03  eta: 0:04:05  time: 0.0534  data_time: 0.0139  memory: 583  loss: 1.7333\n",
      "11/16 19:33:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 180/1563]  lr: 1.0000e-03  eta: 0:04:05  time: 0.0530  data_time: 0.0135  memory: 583  loss: 1.6091\n",
      "11/16 19:33:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 190/1563]  lr: 1.0000e-03  eta: 0:04:04  time: 0.0541  data_time: 0.0144  memory: 583  loss: 1.7022\n",
      "11/16 19:33:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 200/1563]  lr: 1.0000e-03  eta: 0:04:04  time: 0.0530  data_time: 0.0139  memory: 583  loss: 1.8573\n",
      "11/16 19:33:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 210/1563]  lr: 1.0000e-03  eta: 0:04:03  time: 0.0550  data_time: 0.0152  memory: 583  loss: 1.6577\n",
      "11/16 19:33:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 220/1563]  lr: 1.0000e-03  eta: 0:04:03  time: 0.0540  data_time: 0.0145  memory: 583  loss: 1.8743\n",
      "11/16 19:33:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 230/1563]  lr: 1.0000e-03  eta: 0:04:02  time: 0.0589  data_time: 0.0169  memory: 583  loss: 1.8006\n",
      "11/16 19:33:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 240/1563]  lr: 1.0000e-03  eta: 0:04:02  time: 0.0542  data_time: 0.0150  memory: 583  loss: 1.7756\n",
      "11/16 19:33:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 250/1563]  lr: 1.0000e-03  eta: 0:04:01  time: 0.0537  data_time: 0.0143  memory: 583  loss: 1.6863\n",
      "11/16 19:33:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 260/1563]  lr: 1.0000e-03  eta: 0:04:00  time: 0.0552  data_time: 0.0155  memory: 583  loss: 1.7039\n",
      "11/16 19:33:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 270/1563]  lr: 1.0000e-03  eta: 0:04:00  time: 0.0548  data_time: 0.0155  memory: 583  loss: 1.6986\n",
      "11/16 19:33:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 280/1563]  lr: 1.0000e-03  eta: 0:03:59  time: 0.0552  data_time: 0.0153  memory: 583  loss: 1.7122\n",
      "11/16 19:33:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 290/1563]  lr: 1.0000e-03  eta: 0:03:59  time: 0.0536  data_time: 0.0147  memory: 583  loss: 1.7163\n",
      "11/16 19:33:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 300/1563]  lr: 1.0000e-03  eta: 0:03:58  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.6804\n",
      "11/16 19:33:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 310/1563]  lr: 1.0000e-03  eta: 0:03:58  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.6541\n",
      "11/16 19:33:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 320/1563]  lr: 1.0000e-03  eta: 0:03:57  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.5949\n",
      "11/16 19:33:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 330/1563]  lr: 1.0000e-03  eta: 0:03:57  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.6530\n",
      "11/16 19:33:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 340/1563]  lr: 1.0000e-03  eta: 0:03:56  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.6009\n",
      "11/16 19:33:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 350/1563]  lr: 1.0000e-03  eta: 0:03:55  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7795\n",
      "11/16 19:33:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 360/1563]  lr: 1.0000e-03  eta: 0:03:55  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.7391\n",
      "11/16 19:33:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 370/1563]  lr: 1.0000e-03  eta: 0:03:54  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.7473\n",
      "11/16 19:33:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 380/1563]  lr: 1.0000e-03  eta: 0:03:54  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.7001\n",
      "11/16 19:33:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 390/1563]  lr: 1.0000e-03  eta: 0:03:53  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.8269\n",
      "11/16 19:33:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 400/1563]  lr: 1.0000e-03  eta: 0:03:53  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6615\n",
      "11/16 19:33:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 410/1563]  lr: 1.0000e-03  eta: 0:03:52  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.7525\n",
      "11/16 19:33:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 420/1563]  lr: 1.0000e-03  eta: 0:03:51  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6632\n",
      "11/16 19:33:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 430/1563]  lr: 1.0000e-03  eta: 0:03:51  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.7096\n",
      "11/16 19:33:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 440/1563]  lr: 1.0000e-03  eta: 0:03:50  time: 0.0509  data_time: 0.0133  memory: 583  loss: 1.7796\n",
      "11/16 19:33:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 450/1563]  lr: 1.0000e-03  eta: 0:03:50  time: 0.0503  data_time: 0.0133  memory: 583  loss: 1.7139\n",
      "11/16 19:33:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 460/1563]  lr: 1.0000e-03  eta: 0:03:49  time: 0.0518  data_time: 0.0135  memory: 583  loss: 1.6882\n",
      "11/16 19:33:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 470/1563]  lr: 1.0000e-03  eta: 0:03:49  time: 0.0516  data_time: 0.0133  memory: 583  loss: 1.7111\n",
      "11/16 19:34:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 480/1563]  lr: 1.0000e-03  eta: 0:03:48  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.7213\n",
      "11/16 19:34:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 490/1563]  lr: 1.0000e-03  eta: 0:03:47  time: 0.0517  data_time: 0.0134  memory: 583  loss: 1.5724\n",
      "11/16 19:34:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 500/1563]  lr: 1.0000e-03  eta: 0:03:47  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7341\n",
      "11/16 19:34:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 510/1563]  lr: 1.0000e-03  eta: 0:03:46  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6678\n",
      "11/16 19:34:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 520/1563]  lr: 1.0000e-03  eta: 0:03:46  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7692\n",
      "11/16 19:34:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 530/1563]  lr: 1.0000e-03  eta: 0:03:45  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7251\n",
      "11/16 19:34:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 540/1563]  lr: 1.0000e-03  eta: 0:03:45  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7397\n",
      "11/16 19:34:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 550/1563]  lr: 1.0000e-03  eta: 0:03:44  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6523\n",
      "11/16 19:34:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 560/1563]  lr: 1.0000e-03  eta: 0:03:43  time: 0.0530  data_time: 0.0138  memory: 583  loss: 1.6658\n",
      "11/16 19:34:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 570/1563]  lr: 1.0000e-03  eta: 0:03:43  time: 0.0502  data_time: 0.0134  memory: 583  loss: 1.7000\n",
      "11/16 19:34:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 580/1563]  lr: 1.0000e-03  eta: 0:03:42  time: 0.0511  data_time: 0.0134  memory: 583  loss: 1.6418\n",
      "11/16 19:34:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 590/1563]  lr: 1.0000e-03  eta: 0:03:42  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6751\n",
      "11/16 19:34:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 600/1563]  lr: 1.0000e-03  eta: 0:03:41  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.6219\n",
      "11/16 19:34:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 610/1563]  lr: 1.0000e-03  eta: 0:03:41  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.8199\n",
      "11/16 19:34:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 620/1563]  lr: 1.0000e-03  eta: 0:03:40  time: 0.0518  data_time: 0.0132  memory: 583  loss: 1.6300\n",
      "11/16 19:34:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 630/1563]  lr: 1.0000e-03  eta: 0:03:39  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6875\n",
      "11/16 19:34:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 640/1563]  lr: 1.0000e-03  eta: 0:03:39  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.8230\n",
      "11/16 19:34:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 650/1563]  lr: 1.0000e-03  eta: 0:03:38  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.7262\n",
      "11/16 19:34:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 660/1563]  lr: 1.0000e-03  eta: 0:03:38  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.7142\n",
      "11/16 19:34:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 670/1563]  lr: 1.0000e-03  eta: 0:03:37  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6989\n",
      "11/16 19:34:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 680/1563]  lr: 1.0000e-03  eta: 0:03:37  time: 0.0513  data_time: 0.0135  memory: 583  loss: 1.7242\n",
      "11/16 19:34:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 690/1563]  lr: 1.0000e-03  eta: 0:03:36  time: 0.0519  data_time: 0.0135  memory: 583  loss: 1.6707\n",
      "11/16 19:34:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 700/1563]  lr: 1.0000e-03  eta: 0:03:35  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6199\n",
      "11/16 19:34:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 710/1563]  lr: 1.0000e-03  eta: 0:03:35  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.7296\n",
      "11/16 19:34:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 720/1563]  lr: 1.0000e-03  eta: 0:03:34  time: 0.0516  data_time: 0.0133  memory: 583  loss: 1.6454\n",
      "11/16 19:34:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 730/1563]  lr: 1.0000e-03  eta: 0:03:34  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.7502\n",
      "11/16 19:34:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 740/1563]  lr: 1.0000e-03  eta: 0:03:33  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6429\n",
      "11/16 19:34:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 750/1563]  lr: 1.0000e-03  eta: 0:03:33  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.7218\n",
      "11/16 19:34:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 760/1563]  lr: 1.0000e-03  eta: 0:03:32  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.7305\n",
      "11/16 19:34:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 770/1563]  lr: 1.0000e-03  eta: 0:03:31  time: 0.0524  data_time: 0.0137  memory: 583  loss: 1.6878\n",
      "11/16 19:34:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 780/1563]  lr: 1.0000e-03  eta: 0:03:31  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.7743\n",
      "11/16 19:34:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 790/1563]  lr: 1.0000e-03  eta: 0:03:30  time: 0.0518  data_time: 0.0132  memory: 583  loss: 1.6877\n",
      "11/16 19:34:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 800/1563]  lr: 1.0000e-03  eta: 0:03:30  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6350\n",
      "11/16 19:34:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 810/1563]  lr: 1.0000e-03  eta: 0:03:29  time: 0.0515  data_time: 0.0132  memory: 583  loss: 1.6308\n",
      "11/16 19:34:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 820/1563]  lr: 1.0000e-03  eta: 0:03:29  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6440\n",
      "11/16 19:34:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 830/1563]  lr: 1.0000e-03  eta: 0:03:28  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.5148\n",
      "11/16 19:34:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 840/1563]  lr: 1.0000e-03  eta: 0:03:28  time: 0.0522  data_time: 0.0136  memory: 583  loss: 1.6309\n",
      "11/16 19:34:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 850/1563]  lr: 1.0000e-03  eta: 0:03:27  time: 0.0521  data_time: 0.0136  memory: 583  loss: 1.6781\n",
      "11/16 19:34:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 860/1563]  lr: 1.0000e-03  eta: 0:03:26  time: 0.0518  data_time: 0.0132  memory: 583  loss: 1.5909\n",
      "11/16 19:34:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 870/1563]  lr: 1.0000e-03  eta: 0:03:26  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.5640\n",
      "11/16 19:34:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:34:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 880/1563]  lr: 1.0000e-03  eta: 0:03:25  time: 0.0525  data_time: 0.0136  memory: 583  loss: 1.8019\n",
      "11/16 19:34:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 890/1563]  lr: 1.0000e-03  eta: 0:03:25  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6269\n",
      "11/16 19:34:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 900/1563]  lr: 1.0000e-03  eta: 0:03:24  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6528\n",
      "11/16 19:34:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 910/1563]  lr: 1.0000e-03  eta: 0:03:24  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.5432\n",
      "11/16 19:34:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 920/1563]  lr: 1.0000e-03  eta: 0:03:23  time: 0.0519  data_time: 0.0135  memory: 583  loss: 1.5577\n",
      "11/16 19:34:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 930/1563]  lr: 1.0000e-03  eta: 0:03:22  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.6203\n",
      "11/16 19:34:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 940/1563]  lr: 1.0000e-03  eta: 0:03:22  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.6583\n",
      "11/16 19:34:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 950/1563]  lr: 1.0000e-03  eta: 0:03:21  time: 0.0518  data_time: 0.0132  memory: 583  loss: 1.7277\n",
      "11/16 19:34:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 960/1563]  lr: 1.0000e-03  eta: 0:03:21  time: 0.0516  data_time: 0.0133  memory: 583  loss: 1.6505\n",
      "11/16 19:34:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 970/1563]  lr: 1.0000e-03  eta: 0:03:20  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.7238\n",
      "11/16 19:34:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 980/1563]  lr: 1.0000e-03  eta: 0:03:20  time: 0.0515  data_time: 0.0132  memory: 583  loss: 1.6329\n",
      "11/16 19:34:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 990/1563]  lr: 1.0000e-03  eta: 0:03:19  time: 0.0518  data_time: 0.0132  memory: 583  loss: 1.6117\n",
      "11/16 19:34:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1000/1563]  lr: 1.0000e-03  eta: 0:03:19  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.6176\n",
      "11/16 19:34:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1010/1563]  lr: 1.0000e-03  eta: 0:03:18  time: 0.0512  data_time: 0.0135  memory: 583  loss: 1.5579\n",
      "11/16 19:34:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1020/1563]  lr: 1.0000e-03  eta: 0:03:17  time: 0.0501  data_time: 0.0133  memory: 583  loss: 1.6778\n",
      "11/16 19:34:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1030/1563]  lr: 1.0000e-03  eta: 0:03:17  time: 0.0504  data_time: 0.0135  memory: 583  loss: 1.5413\n",
      "11/16 19:34:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1040/1563]  lr: 1.0000e-03  eta: 0:03:16  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.6044\n",
      "11/16 19:34:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1050/1563]  lr: 1.0000e-03  eta: 0:03:16  time: 0.0523  data_time: 0.0136  memory: 583  loss: 1.6741\n",
      "11/16 19:34:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1060/1563]  lr: 1.0000e-03  eta: 0:03:15  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6769\n",
      "11/16 19:34:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1070/1563]  lr: 1.0000e-03  eta: 0:03:15  time: 0.0513  data_time: 0.0131  memory: 583  loss: 1.5650\n",
      "11/16 19:34:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1080/1563]  lr: 1.0000e-03  eta: 0:03:14  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.6365\n",
      "11/16 19:34:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1090/1563]  lr: 1.0000e-03  eta: 0:03:14  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.6537\n",
      "11/16 19:34:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1100/1563]  lr: 1.0000e-03  eta: 0:03:13  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6805\n",
      "11/16 19:34:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1110/1563]  lr: 1.0000e-03  eta: 0:03:12  time: 0.0522  data_time: 0.0136  memory: 583  loss: 1.6337\n",
      "11/16 19:34:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1120/1563]  lr: 1.0000e-03  eta: 0:03:12  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5570\n",
      "11/16 19:34:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1130/1563]  lr: 1.0000e-03  eta: 0:03:11  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.6492\n",
      "11/16 19:34:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1140/1563]  lr: 1.0000e-03  eta: 0:03:11  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5469\n",
      "11/16 19:34:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1150/1563]  lr: 1.0000e-03  eta: 0:03:10  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.6229\n",
      "11/16 19:34:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1160/1563]  lr: 1.0000e-03  eta: 0:03:10  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.5561\n",
      "11/16 19:34:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1170/1563]  lr: 1.0000e-03  eta: 0:03:09  time: 0.0521  data_time: 0.0133  memory: 583  loss: 1.5947\n",
      "11/16 19:34:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1180/1563]  lr: 1.0000e-03  eta: 0:03:09  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.6452\n",
      "11/16 19:34:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1190/1563]  lr: 1.0000e-03  eta: 0:03:08  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6300\n",
      "11/16 19:34:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1200/1563]  lr: 1.0000e-03  eta: 0:03:07  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.6517\n",
      "11/16 19:34:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1210/1563]  lr: 1.0000e-03  eta: 0:03:07  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.6739\n",
      "11/16 19:34:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1220/1563]  lr: 1.0000e-03  eta: 0:03:06  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.6970\n",
      "11/16 19:34:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1230/1563]  lr: 1.0000e-03  eta: 0:03:06  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.6927\n",
      "11/16 19:34:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1240/1563]  lr: 1.0000e-03  eta: 0:03:05  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.6417\n",
      "11/16 19:34:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1250/1563]  lr: 1.0000e-03  eta: 0:03:05  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.5887\n",
      "11/16 19:34:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1260/1563]  lr: 1.0000e-03  eta: 0:03:04  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.6255\n",
      "11/16 19:34:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1270/1563]  lr: 1.0000e-03  eta: 0:03:04  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.6591\n",
      "11/16 19:34:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1280/1563]  lr: 1.0000e-03  eta: 0:03:03  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.6132\n",
      "11/16 19:34:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1290/1563]  lr: 1.0000e-03  eta: 0:03:02  time: 0.0513  data_time: 0.0134  memory: 583  loss: 1.7146\n",
      "11/16 19:34:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1300/1563]  lr: 1.0000e-03  eta: 0:03:02  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6319\n",
      "11/16 19:34:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1310/1563]  lr: 1.0000e-03  eta: 0:03:01  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6219\n",
      "11/16 19:34:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1320/1563]  lr: 1.0000e-03  eta: 0:03:01  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.4518\n",
      "11/16 19:34:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1330/1563]  lr: 1.0000e-03  eta: 0:03:00  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.5846\n",
      "11/16 19:34:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1340/1563]  lr: 1.0000e-03  eta: 0:03:00  time: 0.0523  data_time: 0.0136  memory: 583  loss: 1.6854\n",
      "11/16 19:34:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1350/1563]  lr: 1.0000e-03  eta: 0:02:59  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5629\n",
      "11/16 19:34:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1360/1563]  lr: 1.0000e-03  eta: 0:02:59  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.7074\n",
      "11/16 19:34:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1370/1563]  lr: 1.0000e-03  eta: 0:02:58  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7023\n",
      "11/16 19:34:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1380/1563]  lr: 1.0000e-03  eta: 0:02:57  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5691\n",
      "11/16 19:34:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1390/1563]  lr: 1.0000e-03  eta: 0:02:57  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6268\n",
      "11/16 19:34:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1400/1563]  lr: 1.0000e-03  eta: 0:02:56  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5882\n",
      "11/16 19:34:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1410/1563]  lr: 1.0000e-03  eta: 0:02:56  time: 0.0526  data_time: 0.0136  memory: 583  loss: 1.5840\n",
      "11/16 19:34:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1420/1563]  lr: 1.0000e-03  eta: 0:02:55  time: 0.0523  data_time: 0.0136  memory: 583  loss: 1.5812\n",
      "11/16 19:34:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1430/1563]  lr: 1.0000e-03  eta: 0:02:55  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.8222\n",
      "11/16 19:34:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1440/1563]  lr: 1.0000e-03  eta: 0:02:54  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6268\n",
      "11/16 19:34:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1450/1563]  lr: 1.0000e-03  eta: 0:02:54  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6789\n",
      "11/16 19:34:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1460/1563]  lr: 1.0000e-03  eta: 0:02:53  time: 0.0512  data_time: 0.0133  memory: 583  loss: 1.6895\n",
      "11/16 19:34:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1470/1563]  lr: 1.0000e-03  eta: 0:02:53  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.8220\n",
      "11/16 19:34:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1480/1563]  lr: 1.0000e-03  eta: 0:02:52  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.6938\n",
      "11/16 19:34:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1490/1563]  lr: 1.0000e-03  eta: 0:02:51  time: 0.0519  data_time: 0.0135  memory: 583  loss: 1.6710\n",
      "11/16 19:34:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1500/1563]  lr: 1.0000e-03  eta: 0:02:51  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.4810\n",
      "11/16 19:34:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1510/1563]  lr: 1.0000e-03  eta: 0:02:50  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.6855\n",
      "11/16 19:34:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1520/1563]  lr: 1.0000e-03  eta: 0:02:50  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.6499\n",
      "11/16 19:34:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1530/1563]  lr: 1.0000e-03  eta: 0:02:49  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.6791\n",
      "11/16 19:34:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1540/1563]  lr: 1.0000e-03  eta: 0:02:49  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.6281\n",
      "11/16 19:34:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1550/1563]  lr: 1.0000e-03  eta: 0:02:48  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.5941\n",
      "11/16 19:34:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1560/1563]  lr: 1.0000e-03  eta: 0:02:48  time: 0.0511  data_time: 0.0132  memory: 583  loss: 1.5869\n",
      "11/16 19:34:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:34:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Saving checkpoint at 3 epochs\n",
      "11/16 19:34:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 10/313]    eta: 0:00:05  time: 0.0167  data_time: 0.0083  memory: 583  \n",
      "11/16 19:34:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 20/313]    eta: 0:00:04  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:34:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 30/313]    eta: 0:00:04  time: 0.0171  data_time: 0.0085  memory: 424  \n",
      "11/16 19:34:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 40/313]    eta: 0:00:04  time: 0.0169  data_time: 0.0085  memory: 424  \n",
      "11/16 19:34:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 50/313]    eta: 0:00:04  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:34:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 60/313]    eta: 0:00:04  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:34:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 70/313]    eta: 0:00:04  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:34:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 80/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0084  memory: 424  \n",
      "11/16 19:34:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 90/313]    eta: 0:00:03  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:34:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][100/313]    eta: 0:00:03  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:34:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][110/313]    eta: 0:00:03  time: 0.0171  data_time: 0.0085  memory: 424  \n",
      "11/16 19:34:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][120/313]    eta: 0:00:03  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:34:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][130/313]    eta: 0:00:03  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:34:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][140/313]    eta: 0:00:02  time: 0.0169  data_time: 0.0085  memory: 424  \n",
      "11/16 19:34:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][150/313]    eta: 0:00:02  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:34:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][160/313]    eta: 0:00:02  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:34:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][170/313]    eta: 0:00:02  time: 0.0169  data_time: 0.0085  memory: 424  \n",
      "11/16 19:35:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][180/313]    eta: 0:00:02  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:35:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][190/313]    eta: 0:00:02  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:35:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][200/313]    eta: 0:00:01  time: 0.0168  data_time: 0.0084  memory: 424  \n",
      "11/16 19:35:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][210/313]    eta: 0:00:01  time: 0.0171  data_time: 0.0086  memory: 424  \n",
      "11/16 19:35:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][220/313]    eta: 0:00:01  time: 0.0170  data_time: 0.0085  memory: 424  \n",
      "11/16 19:35:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][230/313]    eta: 0:00:01  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:35:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][240/313]    eta: 0:00:01  time: 0.0168  data_time: 0.0084  memory: 424  \n",
      "11/16 19:35:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][250/313]    eta: 0:00:01  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:35:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][260/313]    eta: 0:00:00  time: 0.0168  data_time: 0.0084  memory: 424  \n",
      "11/16 19:35:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][270/313]    eta: 0:00:00  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:35:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][280/313]    eta: 0:00:00  time: 0.0169  data_time: 0.0085  memory: 424  \n",
      "11/16 19:35:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][290/313]    eta: 0:00:00  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:35:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][300/313]    eta: 0:00:00  time: 0.0168  data_time: 0.0084  memory: 424  \n",
      "11/16 19:35:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][310/313]    eta: 0:00:00  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:35:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][313/313]    accuracy: 45.5000  data_time: 0.0084  time: 0.0168\n",
      "11/16 19:35:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  10/1563]  lr: 1.0000e-03  eta: 0:02:47  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.5607\n",
      "11/16 19:35:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  20/1563]  lr: 1.0000e-03  eta: 0:02:46  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.6224\n",
      "11/16 19:35:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  30/1563]  lr: 1.0000e-03  eta: 0:02:46  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.5670\n",
      "11/16 19:35:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  40/1563]  lr: 1.0000e-03  eta: 0:02:45  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.5347\n",
      "11/16 19:35:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  50/1563]  lr: 1.0000e-03  eta: 0:02:45  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.5120\n",
      "11/16 19:35:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  60/1563]  lr: 1.0000e-03  eta: 0:02:44  time: 0.0522  data_time: 0.0134  memory: 583  loss: 1.5437\n",
      "11/16 19:35:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  70/1563]  lr: 1.0000e-03  eta: 0:02:44  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.7087\n",
      "11/16 19:35:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  80/1563]  lr: 1.0000e-03  eta: 0:02:43  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6404\n",
      "11/16 19:35:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  90/1563]  lr: 1.0000e-03  eta: 0:02:42  time: 0.0508  data_time: 0.0131  memory: 583  loss: 1.4498\n",
      "11/16 19:35:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 100/1563]  lr: 1.0000e-03  eta: 0:02:42  time: 0.0517  data_time: 0.0135  memory: 583  loss: 1.6266\n",
      "11/16 19:35:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 110/1563]  lr: 1.0000e-03  eta: 0:02:41  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.6001\n",
      "11/16 19:35:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 120/1563]  lr: 1.0000e-03  eta: 0:02:41  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5924\n",
      "11/16 19:35:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 130/1563]  lr: 1.0000e-03  eta: 0:02:40  time: 0.0522  data_time: 0.0136  memory: 583  loss: 1.6669\n",
      "11/16 19:35:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 140/1563]  lr: 1.0000e-03  eta: 0:02:40  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5858\n",
      "11/16 19:35:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 150/1563]  lr: 1.0000e-03  eta: 0:02:39  time: 0.0520  data_time: 0.0136  memory: 583  loss: 1.7140\n",
      "11/16 19:35:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 160/1563]  lr: 1.0000e-03  eta: 0:02:39  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.5863\n",
      "11/16 19:35:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 170/1563]  lr: 1.0000e-03  eta: 0:02:38  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.4617\n",
      "11/16 19:35:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 180/1563]  lr: 1.0000e-03  eta: 0:02:38  time: 0.0521  data_time: 0.0133  memory: 583  loss: 1.6065\n",
      "11/16 19:35:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 190/1563]  lr: 1.0000e-03  eta: 0:02:37  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.4972\n",
      "11/16 19:35:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 200/1563]  lr: 1.0000e-03  eta: 0:02:36  time: 0.0513  data_time: 0.0130  memory: 583  loss: 1.5356\n",
      "11/16 19:35:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 210/1563]  lr: 1.0000e-03  eta: 0:02:36  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.5422\n",
      "11/16 19:35:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 220/1563]  lr: 1.0000e-03  eta: 0:02:35  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.4797\n",
      "11/16 19:35:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 230/1563]  lr: 1.0000e-03  eta: 0:02:35  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5629\n",
      "11/16 19:35:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 240/1563]  lr: 1.0000e-03  eta: 0:02:34  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.6657\n",
      "11/16 19:35:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 250/1563]  lr: 1.0000e-03  eta: 0:02:34  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.5348\n",
      "11/16 19:35:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 260/1563]  lr: 1.0000e-03  eta: 0:02:33  time: 0.0519  data_time: 0.0132  memory: 583  loss: 1.5266\n",
      "11/16 19:35:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 270/1563]  lr: 1.0000e-03  eta: 0:02:33  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.5891\n",
      "11/16 19:35:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 280/1563]  lr: 1.0000e-03  eta: 0:02:32  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.6362\n",
      "11/16 19:35:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 290/1563]  lr: 1.0000e-03  eta: 0:02:32  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.7368\n",
      "11/16 19:35:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 300/1563]  lr: 1.0000e-03  eta: 0:02:31  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.6271\n",
      "11/16 19:35:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 310/1563]  lr: 1.0000e-03  eta: 0:02:30  time: 0.0514  data_time: 0.0134  memory: 583  loss: 1.5836\n",
      "11/16 19:35:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:35:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 320/1563]  lr: 1.0000e-03  eta: 0:02:30  time: 0.0526  data_time: 0.0139  memory: 583  loss: 1.5767\n",
      "11/16 19:35:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 330/1563]  lr: 1.0000e-03  eta: 0:02:29  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.5190\n",
      "11/16 19:35:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 340/1563]  lr: 1.0000e-03  eta: 0:02:29  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.4818\n",
      "11/16 19:35:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 350/1563]  lr: 1.0000e-03  eta: 0:02:28  time: 0.0521  data_time: 0.0136  memory: 583  loss: 1.5604\n",
      "11/16 19:35:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 360/1563]  lr: 1.0000e-03  eta: 0:02:28  time: 0.0518  data_time: 0.0132  memory: 583  loss: 1.7209\n",
      "11/16 19:35:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 370/1563]  lr: 1.0000e-03  eta: 0:02:27  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.6530\n",
      "11/16 19:35:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 380/1563]  lr: 1.0000e-03  eta: 0:02:27  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.6377\n",
      "11/16 19:35:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 390/1563]  lr: 1.0000e-03  eta: 0:02:26  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.5516\n",
      "11/16 19:35:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 400/1563]  lr: 1.0000e-03  eta: 0:02:26  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.5795\n",
      "11/16 19:35:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 410/1563]  lr: 1.0000e-03  eta: 0:02:25  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.7536\n",
      "11/16 19:35:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 420/1563]  lr: 1.0000e-03  eta: 0:02:24  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.6067\n",
      "11/16 19:35:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 430/1563]  lr: 1.0000e-03  eta: 0:02:24  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.5970\n",
      "11/16 19:35:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 440/1563]  lr: 1.0000e-03  eta: 0:02:23  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.5953\n",
      "11/16 19:35:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 450/1563]  lr: 1.0000e-03  eta: 0:02:23  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.6145\n",
      "11/16 19:35:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 460/1563]  lr: 1.0000e-03  eta: 0:02:22  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.5111\n",
      "11/16 19:35:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 470/1563]  lr: 1.0000e-03  eta: 0:02:22  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.6105\n",
      "11/16 19:35:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 480/1563]  lr: 1.0000e-03  eta: 0:02:21  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.6430\n",
      "11/16 19:35:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 490/1563]  lr: 1.0000e-03  eta: 0:02:21  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.5662\n",
      "11/16 19:35:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 500/1563]  lr: 1.0000e-03  eta: 0:02:20  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.5906\n",
      "11/16 19:35:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 510/1563]  lr: 1.0000e-03  eta: 0:02:20  time: 0.0516  data_time: 0.0131  memory: 583  loss: 1.6394\n",
      "11/16 19:35:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 520/1563]  lr: 1.0000e-03  eta: 0:02:19  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.5032\n",
      "11/16 19:35:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 530/1563]  lr: 1.0000e-03  eta: 0:02:18  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.6482\n",
      "11/16 19:35:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 540/1563]  lr: 1.0000e-03  eta: 0:02:18  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.6914\n",
      "11/16 19:35:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 550/1563]  lr: 1.0000e-03  eta: 0:02:17  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6061\n",
      "11/16 19:35:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 560/1563]  lr: 1.0000e-03  eta: 0:02:17  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5547\n",
      "11/16 19:35:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 570/1563]  lr: 1.0000e-03  eta: 0:02:16  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.5621\n",
      "11/16 19:35:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 580/1563]  lr: 1.0000e-03  eta: 0:02:16  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5626\n",
      "11/16 19:35:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 590/1563]  lr: 1.0000e-03  eta: 0:02:15  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.5019\n",
      "11/16 19:35:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 600/1563]  lr: 1.0000e-03  eta: 0:02:15  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.6926\n",
      "11/16 19:35:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 610/1563]  lr: 1.0000e-03  eta: 0:02:14  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.4765\n",
      "11/16 19:35:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 620/1563]  lr: 1.0000e-03  eta: 0:02:14  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.6460\n",
      "11/16 19:35:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 630/1563]  lr: 1.0000e-03  eta: 0:02:13  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.5182\n",
      "11/16 19:35:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 640/1563]  lr: 1.0000e-03  eta: 0:02:12  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.6307\n",
      "11/16 19:35:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 650/1563]  lr: 1.0000e-03  eta: 0:02:12  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.6553\n",
      "11/16 19:35:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 660/1563]  lr: 1.0000e-03  eta: 0:02:11  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.5777\n",
      "11/16 19:35:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 670/1563]  lr: 1.0000e-03  eta: 0:02:11  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.5607\n",
      "11/16 19:35:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 680/1563]  lr: 1.0000e-03  eta: 0:02:10  time: 0.0522  data_time: 0.0134  memory: 583  loss: 1.5438\n",
      "11/16 19:35:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 690/1563]  lr: 1.0000e-03  eta: 0:02:10  time: 0.0523  data_time: 0.0136  memory: 583  loss: 1.6494\n",
      "11/16 19:35:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 700/1563]  lr: 1.0000e-03  eta: 0:02:09  time: 0.0512  data_time: 0.0133  memory: 583  loss: 1.5733\n",
      "11/16 19:35:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 710/1563]  lr: 1.0000e-03  eta: 0:02:09  time: 0.0519  data_time: 0.0135  memory: 583  loss: 1.6367\n",
      "11/16 19:35:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 720/1563]  lr: 1.0000e-03  eta: 0:02:08  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5514\n",
      "11/16 19:35:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 730/1563]  lr: 1.0000e-03  eta: 0:02:08  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.6155\n",
      "11/16 19:35:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 740/1563]  lr: 1.0000e-03  eta: 0:02:07  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5856\n",
      "11/16 19:35:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 750/1563]  lr: 1.0000e-03  eta: 0:02:07  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.5818\n",
      "11/16 19:35:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 760/1563]  lr: 1.0000e-03  eta: 0:02:06  time: 0.0526  data_time: 0.0136  memory: 583  loss: 1.5806\n",
      "11/16 19:35:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 770/1563]  lr: 1.0000e-03  eta: 0:02:05  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.5392\n",
      "11/16 19:35:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 780/1563]  lr: 1.0000e-03  eta: 0:02:05  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5545\n",
      "11/16 19:35:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 790/1563]  lr: 1.0000e-03  eta: 0:02:04  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.4785\n",
      "11/16 19:35:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 800/1563]  lr: 1.0000e-03  eta: 0:02:04  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.6271\n",
      "11/16 19:35:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 810/1563]  lr: 1.0000e-03  eta: 0:02:03  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.6067\n",
      "11/16 19:35:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 820/1563]  lr: 1.0000e-03  eta: 0:02:03  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.7234\n",
      "11/16 19:35:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 830/1563]  lr: 1.0000e-03  eta: 0:02:02  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.4992\n",
      "11/16 19:35:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 840/1563]  lr: 1.0000e-03  eta: 0:02:02  time: 0.0523  data_time: 0.0136  memory: 583  loss: 1.5843\n",
      "11/16 19:35:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 850/1563]  lr: 1.0000e-03  eta: 0:02:01  time: 0.0523  data_time: 0.0136  memory: 583  loss: 1.8102\n",
      "11/16 19:35:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 860/1563]  lr: 1.0000e-03  eta: 0:02:01  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.5565\n",
      "11/16 19:35:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 870/1563]  lr: 1.0000e-03  eta: 0:02:00  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.5670\n",
      "11/16 19:35:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 880/1563]  lr: 1.0000e-03  eta: 0:02:00  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.6017\n",
      "11/16 19:35:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 890/1563]  lr: 1.0000e-03  eta: 0:01:59  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.5105\n",
      "11/16 19:35:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 900/1563]  lr: 1.0000e-03  eta: 0:01:58  time: 0.0519  data_time: 0.0135  memory: 583  loss: 1.6366\n",
      "11/16 19:35:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 910/1563]  lr: 1.0000e-03  eta: 0:01:58  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.4760\n",
      "11/16 19:35:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 920/1563]  lr: 1.0000e-03  eta: 0:01:57  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.5833\n",
      "11/16 19:35:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 930/1563]  lr: 1.0000e-03  eta: 0:01:57  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5323\n",
      "11/16 19:35:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 940/1563]  lr: 1.0000e-03  eta: 0:01:56  time: 0.0517  data_time: 0.0132  memory: 583  loss: 1.5967\n",
      "11/16 19:35:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 950/1563]  lr: 1.0000e-03  eta: 0:01:56  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.6286\n",
      "11/16 19:35:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 960/1563]  lr: 1.0000e-03  eta: 0:01:55  time: 0.0517  data_time: 0.0134  memory: 583  loss: 1.5687\n",
      "11/16 19:35:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 970/1563]  lr: 1.0000e-03  eta: 0:01:55  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.5091\n",
      "11/16 19:35:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 980/1563]  lr: 1.0000e-03  eta: 0:01:54  time: 0.0524  data_time: 0.0137  memory: 583  loss: 1.5775\n",
      "11/16 19:35:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 990/1563]  lr: 1.0000e-03  eta: 0:01:54  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.5355\n",
      "11/16 19:35:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1000/1563]  lr: 1.0000e-03  eta: 0:01:53  time: 0.0525  data_time: 0.0137  memory: 583  loss: 1.5327\n",
      "11/16 19:35:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1010/1563]  lr: 1.0000e-03  eta: 0:01:52  time: 0.0525  data_time: 0.0137  memory: 583  loss: 1.5377\n",
      "11/16 19:35:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1020/1563]  lr: 1.0000e-03  eta: 0:01:52  time: 0.0527  data_time: 0.0138  memory: 583  loss: 1.5830\n",
      "11/16 19:35:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1030/1563]  lr: 1.0000e-03  eta: 0:01:51  time: 0.0525  data_time: 0.0137  memory: 583  loss: 1.5977\n",
      "11/16 19:35:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1040/1563]  lr: 1.0000e-03  eta: 0:01:51  time: 0.0525  data_time: 0.0138  memory: 583  loss: 1.5331\n",
      "11/16 19:35:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1050/1563]  lr: 1.0000e-03  eta: 0:01:50  time: 0.0528  data_time: 0.0139  memory: 583  loss: 1.5030\n",
      "11/16 19:35:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1060/1563]  lr: 1.0000e-03  eta: 0:01:50  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.6630\n",
      "11/16 19:35:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1070/1563]  lr: 1.0000e-03  eta: 0:01:49  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.5678\n",
      "11/16 19:35:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1080/1563]  lr: 1.0000e-03  eta: 0:01:49  time: 0.0525  data_time: 0.0137  memory: 583  loss: 1.6587\n",
      "11/16 19:35:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1090/1563]  lr: 1.0000e-03  eta: 0:01:48  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5858\n",
      "11/16 19:35:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1100/1563]  lr: 1.0000e-03  eta: 0:01:48  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.6455\n",
      "11/16 19:36:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1110/1563]  lr: 1.0000e-03  eta: 0:01:47  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.4323\n",
      "11/16 19:36:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1120/1563]  lr: 1.0000e-03  eta: 0:01:47  time: 0.0690  data_time: 0.0277  memory: 583  loss: 1.5821\n",
      "11/16 19:36:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1130/1563]  lr: 1.0000e-03  eta: 0:01:46  time: 0.0565  data_time: 0.0156  memory: 583  loss: 1.4582\n",
      "11/16 19:36:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1140/1563]  lr: 1.0000e-03  eta: 0:01:46  time: 0.0564  data_time: 0.0154  memory: 583  loss: 1.5141\n",
      "11/16 19:36:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1150/1563]  lr: 1.0000e-03  eta: 0:01:45  time: 0.0562  data_time: 0.0153  memory: 583  loss: 1.5818\n",
      "11/16 19:36:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1160/1563]  lr: 1.0000e-03  eta: 0:01:45  time: 0.0562  data_time: 0.0153  memory: 583  loss: 1.5350\n",
      "11/16 19:36:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1170/1563]  lr: 1.0000e-03  eta: 0:01:44  time: 0.0563  data_time: 0.0155  memory: 583  loss: 1.4803\n",
      "11/16 19:36:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1180/1563]  lr: 1.0000e-03  eta: 0:01:43  time: 0.0563  data_time: 0.0154  memory: 583  loss: 1.4910\n",
      "11/16 19:36:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1190/1563]  lr: 1.0000e-03  eta: 0:01:43  time: 0.0563  data_time: 0.0155  memory: 583  loss: 1.4926\n",
      "11/16 19:36:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1200/1563]  lr: 1.0000e-03  eta: 0:01:42  time: 0.0565  data_time: 0.0155  memory: 583  loss: 1.6220\n",
      "11/16 19:36:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1210/1563]  lr: 1.0000e-03  eta: 0:01:42  time: 0.0565  data_time: 0.0155  memory: 583  loss: 1.4857\n",
      "11/16 19:36:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1220/1563]  lr: 1.0000e-03  eta: 0:01:41  time: 0.0562  data_time: 0.0154  memory: 583  loss: 1.4314\n",
      "11/16 19:36:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1230/1563]  lr: 1.0000e-03  eta: 0:01:41  time: 0.0562  data_time: 0.0153  memory: 583  loss: 1.6568\n",
      "11/16 19:36:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1240/1563]  lr: 1.0000e-03  eta: 0:01:40  time: 0.0561  data_time: 0.0153  memory: 583  loss: 1.5729\n",
      "11/16 19:36:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1250/1563]  lr: 1.0000e-03  eta: 0:01:40  time: 0.0561  data_time: 0.0153  memory: 583  loss: 1.5035\n",
      "11/16 19:36:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1260/1563]  lr: 1.0000e-03  eta: 0:01:39  time: 0.0561  data_time: 0.0153  memory: 583  loss: 1.5118\n",
      "11/16 19:36:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1270/1563]  lr: 1.0000e-03  eta: 0:01:39  time: 0.0562  data_time: 0.0154  memory: 583  loss: 1.5899\n",
      "11/16 19:36:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1280/1563]  lr: 1.0000e-03  eta: 0:01:38  time: 0.0561  data_time: 0.0153  memory: 583  loss: 1.5077\n",
      "11/16 19:36:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1290/1563]  lr: 1.0000e-03  eta: 0:01:38  time: 0.0564  data_time: 0.0154  memory: 583  loss: 1.5095\n",
      "11/16 19:36:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1300/1563]  lr: 1.0000e-03  eta: 0:01:37  time: 0.0563  data_time: 0.0154  memory: 583  loss: 1.6233\n",
      "11/16 19:36:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1310/1563]  lr: 1.0000e-03  eta: 0:01:37  time: 0.0562  data_time: 0.0154  memory: 583  loss: 1.5511\n",
      "11/16 19:36:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:36:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1320/1563]  lr: 1.0000e-03  eta: 0:01:36  time: 0.0569  data_time: 0.0159  memory: 583  loss: 1.4975\n",
      "11/16 19:36:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1330/1563]  lr: 1.0000e-03  eta: 0:01:36  time: 0.0560  data_time: 0.0152  memory: 583  loss: 1.5573\n",
      "11/16 19:36:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1340/1563]  lr: 1.0000e-03  eta: 0:01:35  time: 0.0561  data_time: 0.0153  memory: 583  loss: 1.5318\n",
      "11/16 19:36:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1350/1563]  lr: 1.0000e-03  eta: 0:01:35  time: 0.0562  data_time: 0.0153  memory: 583  loss: 1.4151\n",
      "11/16 19:36:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1360/1563]  lr: 1.0000e-03  eta: 0:01:34  time: 0.0561  data_time: 0.0153  memory: 583  loss: 1.6054\n",
      "11/16 19:36:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1370/1563]  lr: 1.0000e-03  eta: 0:01:33  time: 0.0562  data_time: 0.0154  memory: 583  loss: 1.6002\n",
      "11/16 19:36:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1380/1563]  lr: 1.0000e-03  eta: 0:01:33  time: 0.0563  data_time: 0.0154  memory: 583  loss: 1.5828\n",
      "11/16 19:36:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1390/1563]  lr: 1.0000e-03  eta: 0:01:32  time: 0.0566  data_time: 0.0155  memory: 583  loss: 1.3907\n",
      "11/16 19:36:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1400/1563]  lr: 1.0000e-03  eta: 0:01:32  time: 0.0564  data_time: 0.0155  memory: 583  loss: 1.5694\n",
      "11/16 19:36:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1410/1563]  lr: 1.0000e-03  eta: 0:01:31  time: 0.0563  data_time: 0.0153  memory: 583  loss: 1.5473\n",
      "11/16 19:36:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1420/1563]  lr: 1.0000e-03  eta: 0:01:31  time: 0.0561  data_time: 0.0153  memory: 583  loss: 1.6656\n",
      "11/16 19:36:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1430/1563]  lr: 1.0000e-03  eta: 0:01:30  time: 0.0563  data_time: 0.0153  memory: 583  loss: 1.6371\n",
      "11/16 19:36:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1440/1563]  lr: 1.0000e-03  eta: 0:01:30  time: 0.0562  data_time: 0.0154  memory: 583  loss: 1.5560\n",
      "11/16 19:36:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1450/1563]  lr: 1.0000e-03  eta: 0:01:29  time: 0.0563  data_time: 0.0154  memory: 583  loss: 1.4844\n",
      "11/16 19:36:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1460/1563]  lr: 1.0000e-03  eta: 0:01:29  time: 0.0561  data_time: 0.0154  memory: 583  loss: 1.5168\n",
      "11/16 19:36:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1470/1563]  lr: 1.0000e-03  eta: 0:01:28  time: 0.0563  data_time: 0.0154  memory: 583  loss: 1.4785\n",
      "11/16 19:36:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1480/1563]  lr: 1.0000e-03  eta: 0:01:28  time: 0.0564  data_time: 0.0156  memory: 583  loss: 1.5309\n",
      "11/16 19:36:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1490/1563]  lr: 1.0000e-03  eta: 0:01:27  time: 0.0565  data_time: 0.0155  memory: 583  loss: 1.5986\n",
      "11/16 19:36:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1500/1563]  lr: 1.0000e-03  eta: 0:01:27  time: 0.0566  data_time: 0.0155  memory: 583  loss: 1.5646\n",
      "11/16 19:36:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1510/1563]  lr: 1.0000e-03  eta: 0:01:26  time: 0.0562  data_time: 0.0154  memory: 583  loss: 1.6112\n",
      "11/16 19:36:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1520/1563]  lr: 1.0000e-03  eta: 0:01:26  time: 0.0563  data_time: 0.0153  memory: 583  loss: 1.5362\n",
      "11/16 19:36:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1530/1563]  lr: 1.0000e-03  eta: 0:01:25  time: 0.0561  data_time: 0.0153  memory: 583  loss: 1.6157\n",
      "11/16 19:36:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1540/1563]  lr: 1.0000e-03  eta: 0:01:25  time: 0.0563  data_time: 0.0153  memory: 583  loss: 1.5889\n",
      "11/16 19:36:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1550/1563]  lr: 1.0000e-03  eta: 0:01:24  time: 0.0563  data_time: 0.0154  memory: 583  loss: 1.5280\n",
      "11/16 19:36:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1560/1563]  lr: 1.0000e-03  eta: 0:01:23  time: 0.0563  data_time: 0.0154  memory: 583  loss: 1.5604\n",
      "11/16 19:36:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:36:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Saving checkpoint at 4 epochs\n",
      "11/16 19:36:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 10/313]    eta: 0:00:05  time: 0.0197  data_time: 0.0097  memory: 583  \n",
      "11/16 19:36:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 20/313]    eta: 0:00:05  time: 0.0181  data_time: 0.0091  memory: 424  \n",
      "11/16 19:36:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 30/313]    eta: 0:00:05  time: 0.0170  data_time: 0.0086  memory: 424  \n",
      "11/16 19:36:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 40/313]    eta: 0:00:04  time: 0.0168  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 50/313]    eta: 0:00:04  time: 0.0168  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 60/313]    eta: 0:00:04  time: 0.0170  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 70/313]    eta: 0:00:04  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 80/313]    eta: 0:00:04  time: 0.0168  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 90/313]    eta: 0:00:03  time: 0.0170  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][100/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][110/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][120/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][130/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][140/313]    eta: 0:00:02  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][150/313]    eta: 0:00:02  time: 0.0173  data_time: 0.0087  memory: 424  \n",
      "11/16 19:36:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][160/313]    eta: 0:00:02  time: 0.0170  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][170/313]    eta: 0:00:02  time: 0.0169  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][180/313]    eta: 0:00:02  time: 0.0168  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][190/313]    eta: 0:00:02  time: 0.0169  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][200/313]    eta: 0:00:01  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][210/313]    eta: 0:00:01  time: 0.0169  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][220/313]    eta: 0:00:01  time: 0.0168  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][230/313]    eta: 0:00:01  time: 0.0171  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][240/313]    eta: 0:00:01  time: 0.0169  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][250/313]    eta: 0:00:01  time: 0.0170  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][260/313]    eta: 0:00:00  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][270/313]    eta: 0:00:00  time: 0.0169  data_time: 0.0084  memory: 424  \n",
      "11/16 19:36:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][280/313]    eta: 0:00:00  time: 0.0170  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][290/313]    eta: 0:00:00  time: 0.0169  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][300/313]    eta: 0:00:00  time: 0.0168  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][310/313]    eta: 0:00:00  time: 0.0170  data_time: 0.0085  memory: 424  \n",
      "11/16 19:36:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][313/313]    accuracy: 48.1000  data_time: 0.0085  time: 0.0170\n",
      "11/16 19:36:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  10/1563]  lr: 1.0000e-03  eta: 0:01:23  time: 0.0515  data_time: 0.0131  memory: 583  loss: 1.4898\n",
      "11/16 19:36:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  20/1563]  lr: 1.0000e-03  eta: 0:01:22  time: 0.0516  data_time: 0.0132  memory: 583  loss: 1.4765\n",
      "11/16 19:36:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  30/1563]  lr: 1.0000e-03  eta: 0:01:22  time: 0.0551  data_time: 0.0149  memory: 583  loss: 1.6208\n",
      "11/16 19:36:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  40/1563]  lr: 1.0000e-03  eta: 0:01:21  time: 0.0525  data_time: 0.0136  memory: 583  loss: 1.5789\n",
      "11/16 19:36:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  50/1563]  lr: 1.0000e-03  eta: 0:01:21  time: 0.0528  data_time: 0.0137  memory: 583  loss: 1.5925\n",
      "11/16 19:36:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  60/1563]  lr: 1.0000e-03  eta: 0:01:20  time: 0.0530  data_time: 0.0139  memory: 583  loss: 1.6478\n",
      "11/16 19:36:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  70/1563]  lr: 1.0000e-03  eta: 0:01:20  time: 0.0527  data_time: 0.0136  memory: 583  loss: 1.4172\n",
      "11/16 19:36:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  80/1563]  lr: 1.0000e-03  eta: 0:01:19  time: 0.0532  data_time: 0.0141  memory: 583  loss: 1.5051\n",
      "11/16 19:36:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  90/1563]  lr: 1.0000e-03  eta: 0:01:18  time: 0.0525  data_time: 0.0136  memory: 583  loss: 1.5325\n",
      "11/16 19:36:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 100/1563]  lr: 1.0000e-03  eta: 0:01:18  time: 0.0526  data_time: 0.0137  memory: 583  loss: 1.5734\n",
      "11/16 19:36:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 110/1563]  lr: 1.0000e-03  eta: 0:01:17  time: 0.0526  data_time: 0.0136  memory: 583  loss: 1.5382\n",
      "11/16 19:36:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 120/1563]  lr: 1.0000e-03  eta: 0:01:17  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.5414\n",
      "11/16 19:36:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 130/1563]  lr: 1.0000e-03  eta: 0:01:16  time: 0.0529  data_time: 0.0138  memory: 583  loss: 1.4464\n",
      "11/16 19:36:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 140/1563]  lr: 1.0000e-03  eta: 0:01:16  time: 0.0529  data_time: 0.0138  memory: 583  loss: 1.4153\n",
      "11/16 19:36:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 150/1563]  lr: 1.0000e-03  eta: 0:01:15  time: 0.0529  data_time: 0.0137  memory: 583  loss: 1.5358\n",
      "11/16 19:36:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 160/1563]  lr: 1.0000e-03  eta: 0:01:15  time: 0.0528  data_time: 0.0138  memory: 583  loss: 1.5253\n",
      "11/16 19:36:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 170/1563]  lr: 1.0000e-03  eta: 0:01:14  time: 0.0528  data_time: 0.0137  memory: 583  loss: 1.5026\n",
      "11/16 19:36:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 180/1563]  lr: 1.0000e-03  eta: 0:01:14  time: 0.0528  data_time: 0.0138  memory: 583  loss: 1.5032\n",
      "11/16 19:36:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 190/1563]  lr: 1.0000e-03  eta: 0:01:13  time: 0.0526  data_time: 0.0136  memory: 583  loss: 1.5401\n",
      "11/16 19:36:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 200/1563]  lr: 1.0000e-03  eta: 0:01:13  time: 0.0535  data_time: 0.0140  memory: 583  loss: 1.5001\n",
      "11/16 19:36:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 210/1563]  lr: 1.0000e-03  eta: 0:01:12  time: 0.0538  data_time: 0.0142  memory: 583  loss: 1.6214\n",
      "11/16 19:36:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 220/1563]  lr: 1.0000e-03  eta: 0:01:11  time: 0.0527  data_time: 0.0136  memory: 583  loss: 1.3950\n",
      "11/16 19:36:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 230/1563]  lr: 1.0000e-03  eta: 0:01:11  time: 0.0530  data_time: 0.0136  memory: 583  loss: 1.6352\n",
      "11/16 19:36:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 240/1563]  lr: 1.0000e-03  eta: 0:01:10  time: 0.0543  data_time: 0.0144  memory: 583  loss: 1.4896\n",
      "11/16 19:36:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 250/1563]  lr: 1.0000e-03  eta: 0:01:10  time: 0.0543  data_time: 0.0144  memory: 583  loss: 1.4954\n",
      "11/16 19:36:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 260/1563]  lr: 1.0000e-03  eta: 0:01:09  time: 0.0530  data_time: 0.0138  memory: 583  loss: 1.5834\n",
      "11/16 19:36:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 270/1563]  lr: 1.0000e-03  eta: 0:01:09  time: 0.0526  data_time: 0.0138  memory: 583  loss: 1.6811\n",
      "11/16 19:36:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 280/1563]  lr: 1.0000e-03  eta: 0:01:08  time: 0.0529  data_time: 0.0138  memory: 583  loss: 1.5205\n",
      "11/16 19:36:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 290/1563]  lr: 1.0000e-03  eta: 0:01:08  time: 0.0526  data_time: 0.0137  memory: 583  loss: 1.5678\n",
      "11/16 19:36:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 300/1563]  lr: 1.0000e-03  eta: 0:01:07  time: 0.0530  data_time: 0.0138  memory: 583  loss: 1.4220\n",
      "11/16 19:36:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 310/1563]  lr: 1.0000e-03  eta: 0:01:07  time: 0.0527  data_time: 0.0136  memory: 583  loss: 1.4808\n",
      "11/16 19:36:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 320/1563]  lr: 1.0000e-03  eta: 0:01:06  time: 0.0528  data_time: 0.0138  memory: 583  loss: 1.5319\n",
      "11/16 19:36:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 330/1563]  lr: 1.0000e-03  eta: 0:01:06  time: 0.0530  data_time: 0.0139  memory: 583  loss: 1.5735\n",
      "11/16 19:36:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 340/1563]  lr: 1.0000e-03  eta: 0:01:05  time: 0.0529  data_time: 0.0137  memory: 583  loss: 1.4347\n",
      "11/16 19:36:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 350/1563]  lr: 1.0000e-03  eta: 0:01:04  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.4799\n",
      "11/16 19:36:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 360/1563]  lr: 1.0000e-03  eta: 0:01:04  time: 0.0528  data_time: 0.0137  memory: 583  loss: 1.4012\n",
      "11/16 19:36:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 370/1563]  lr: 1.0000e-03  eta: 0:01:03  time: 0.0530  data_time: 0.0137  memory: 583  loss: 1.4668\n",
      "11/16 19:36:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 380/1563]  lr: 1.0000e-03  eta: 0:01:03  time: 0.0525  data_time: 0.0136  memory: 583  loss: 1.4760\n",
      "11/16 19:36:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 390/1563]  lr: 1.0000e-03  eta: 0:01:02  time: 0.0527  data_time: 0.0138  memory: 583  loss: 1.6199\n",
      "11/16 19:36:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 400/1563]  lr: 1.0000e-03  eta: 0:01:02  time: 0.0527  data_time: 0.0137  memory: 583  loss: 1.5602\n",
      "11/16 19:36:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 410/1563]  lr: 1.0000e-03  eta: 0:01:01  time: 0.0529  data_time: 0.0139  memory: 583  loss: 1.5030\n",
      "11/16 19:36:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 420/1563]  lr: 1.0000e-03  eta: 0:01:01  time: 0.0527  data_time: 0.0137  memory: 583  loss: 1.5223\n",
      "11/16 19:36:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 430/1563]  lr: 1.0000e-03  eta: 0:01:00  time: 0.0528  data_time: 0.0137  memory: 583  loss: 1.4740\n",
      "11/16 19:36:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 440/1563]  lr: 1.0000e-03  eta: 0:01:00  time: 0.0530  data_time: 0.0138  memory: 583  loss: 1.5722\n",
      "11/16 19:36:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 450/1563]  lr: 1.0000e-03  eta: 0:00:59  time: 0.0529  data_time: 0.0137  memory: 583  loss: 1.5297\n",
      "11/16 19:36:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 460/1563]  lr: 1.0000e-03  eta: 0:00:59  time: 0.0530  data_time: 0.0139  memory: 583  loss: 1.5597\n",
      "11/16 19:36:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 470/1563]  lr: 1.0000e-03  eta: 0:00:58  time: 0.0529  data_time: 0.0140  memory: 583  loss: 1.5702\n",
      "11/16 19:36:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 480/1563]  lr: 1.0000e-03  eta: 0:00:58  time: 0.0528  data_time: 0.0137  memory: 583  loss: 1.6565\n",
      "11/16 19:36:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 490/1563]  lr: 1.0000e-03  eta: 0:00:57  time: 0.0526  data_time: 0.0137  memory: 583  loss: 1.4949\n",
      "11/16 19:36:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 500/1563]  lr: 1.0000e-03  eta: 0:00:56  time: 0.0530  data_time: 0.0139  memory: 583  loss: 1.5098\n",
      "11/16 19:36:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 510/1563]  lr: 1.0000e-03  eta: 0:00:56  time: 0.0531  data_time: 0.0140  memory: 583  loss: 1.5387\n",
      "11/16 19:36:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 520/1563]  lr: 1.0000e-03  eta: 0:00:55  time: 0.0529  data_time: 0.0138  memory: 583  loss: 1.5758\n",
      "11/16 19:36:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 530/1563]  lr: 1.0000e-03  eta: 0:00:55  time: 0.0525  data_time: 0.0136  memory: 583  loss: 1.5320\n",
      "11/16 19:37:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 540/1563]  lr: 1.0000e-03  eta: 0:00:54  time: 0.0529  data_time: 0.0138  memory: 583  loss: 1.6817\n",
      "11/16 19:37:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 550/1563]  lr: 1.0000e-03  eta: 0:00:54  time: 0.0525  data_time: 0.0137  memory: 583  loss: 1.3118\n",
      "11/16 19:37:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 560/1563]  lr: 1.0000e-03  eta: 0:00:53  time: 0.0526  data_time: 0.0137  memory: 583  loss: 1.5294\n",
      "11/16 19:37:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 570/1563]  lr: 1.0000e-03  eta: 0:00:53  time: 0.0524  data_time: 0.0135  memory: 583  loss: 1.5879\n",
      "11/16 19:37:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 580/1563]  lr: 1.0000e-03  eta: 0:00:52  time: 0.0528  data_time: 0.0137  memory: 583  loss: 1.5371\n",
      "11/16 19:37:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 590/1563]  lr: 1.0000e-03  eta: 0:00:52  time: 0.0526  data_time: 0.0137  memory: 583  loss: 1.5631\n",
      "11/16 19:37:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 600/1563]  lr: 1.0000e-03  eta: 0:00:51  time: 0.0529  data_time: 0.0138  memory: 583  loss: 1.5269\n",
      "11/16 19:37:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 610/1563]  lr: 1.0000e-03  eta: 0:00:51  time: 0.0525  data_time: 0.0136  memory: 583  loss: 1.4735\n",
      "11/16 19:37:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 620/1563]  lr: 1.0000e-03  eta: 0:00:50  time: 0.0530  data_time: 0.0138  memory: 583  loss: 1.6116\n",
      "11/16 19:37:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 630/1563]  lr: 1.0000e-03  eta: 0:00:49  time: 0.0530  data_time: 0.0139  memory: 583  loss: 1.5450\n",
      "11/16 19:37:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 640/1563]  lr: 1.0000e-03  eta: 0:00:49  time: 0.0530  data_time: 0.0138  memory: 583  loss: 1.5807\n",
      "11/16 19:37:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 650/1563]  lr: 1.0000e-03  eta: 0:00:48  time: 0.0531  data_time: 0.0139  memory: 583  loss: 1.6075\n",
      "11/16 19:37:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 660/1563]  lr: 1.0000e-03  eta: 0:00:48  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.4707\n",
      "11/16 19:37:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 670/1563]  lr: 1.0000e-03  eta: 0:00:47  time: 0.0532  data_time: 0.0141  memory: 583  loss: 1.4897\n",
      "11/16 19:37:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 680/1563]  lr: 1.0000e-03  eta: 0:00:47  time: 0.0525  data_time: 0.0137  memory: 583  loss: 1.5033\n",
      "11/16 19:37:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 690/1563]  lr: 1.0000e-03  eta: 0:00:46  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.4563\n",
      "11/16 19:37:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 700/1563]  lr: 1.0000e-03  eta: 0:00:46  time: 0.0524  data_time: 0.0135  memory: 583  loss: 1.4896\n",
      "11/16 19:37:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 710/1563]  lr: 1.0000e-03  eta: 0:00:45  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.4151\n",
      "11/16 19:37:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 720/1563]  lr: 1.0000e-03  eta: 0:00:45  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.5665\n",
      "11/16 19:37:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 730/1563]  lr: 1.0000e-03  eta: 0:00:44  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.5743\n",
      "11/16 19:37:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 740/1563]  lr: 1.0000e-03  eta: 0:00:44  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.4464\n",
      "11/16 19:37:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:37:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 750/1563]  lr: 1.0000e-03  eta: 0:00:43  time: 0.0532  data_time: 0.0141  memory: 583  loss: 1.4977\n",
      "11/16 19:37:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 760/1563]  lr: 1.0000e-03  eta: 0:00:42  time: 0.0519  data_time: 0.0132  memory: 583  loss: 1.5969\n",
      "11/16 19:37:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 770/1563]  lr: 1.0000e-03  eta: 0:00:42  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.4688\n",
      "11/16 19:37:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 780/1563]  lr: 1.0000e-03  eta: 0:00:41  time: 0.0519  data_time: 0.0135  memory: 583  loss: 1.4980\n",
      "11/16 19:37:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 790/1563]  lr: 1.0000e-03  eta: 0:00:41  time: 0.0522  data_time: 0.0134  memory: 583  loss: 1.4763\n",
      "11/16 19:37:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 800/1563]  lr: 1.0000e-03  eta: 0:00:40  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.3775\n",
      "11/16 19:37:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 810/1563]  lr: 1.0000e-03  eta: 0:00:40  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5056\n",
      "11/16 19:37:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 820/1563]  lr: 1.0000e-03  eta: 0:00:39  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5930\n",
      "11/16 19:37:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 830/1563]  lr: 1.0000e-03  eta: 0:00:39  time: 0.0522  data_time: 0.0134  memory: 583  loss: 1.5652\n",
      "11/16 19:37:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 840/1563]  lr: 1.0000e-03  eta: 0:00:38  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.4322\n",
      "11/16 19:37:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 850/1563]  lr: 1.0000e-03  eta: 0:00:38  time: 0.0523  data_time: 0.0137  memory: 583  loss: 1.3475\n",
      "11/16 19:37:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 860/1563]  lr: 1.0000e-03  eta: 0:00:37  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5206\n",
      "11/16 19:37:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 870/1563]  lr: 1.0000e-03  eta: 0:00:37  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.4609\n",
      "11/16 19:37:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 880/1563]  lr: 1.0000e-03  eta: 0:00:36  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.5457\n",
      "11/16 19:37:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 890/1563]  lr: 1.0000e-03  eta: 0:00:36  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.5227\n",
      "11/16 19:37:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 900/1563]  lr: 1.0000e-03  eta: 0:00:35  time: 0.0523  data_time: 0.0136  memory: 583  loss: 1.4527\n",
      "11/16 19:37:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 910/1563]  lr: 1.0000e-03  eta: 0:00:34  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.4892\n",
      "11/16 19:37:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 920/1563]  lr: 1.0000e-03  eta: 0:00:34  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.6151\n",
      "11/16 19:37:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 930/1563]  lr: 1.0000e-03  eta: 0:00:33  time: 0.0523  data_time: 0.0137  memory: 583  loss: 1.5074\n",
      "11/16 19:37:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 940/1563]  lr: 1.0000e-03  eta: 0:00:33  time: 0.0523  data_time: 0.0136  memory: 583  loss: 1.5901\n",
      "11/16 19:37:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 950/1563]  lr: 1.0000e-03  eta: 0:00:32  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.6118\n",
      "11/16 19:37:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 960/1563]  lr: 1.0000e-03  eta: 0:00:32  time: 0.0512  data_time: 0.0135  memory: 583  loss: 1.4956\n",
      "11/16 19:37:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 970/1563]  lr: 1.0000e-03  eta: 0:00:31  time: 0.0516  data_time: 0.0134  memory: 583  loss: 1.4863\n",
      "11/16 19:37:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 980/1563]  lr: 1.0000e-03  eta: 0:00:31  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.4141\n",
      "11/16 19:37:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 990/1563]  lr: 1.0000e-03  eta: 0:00:30  time: 0.0520  data_time: 0.0132  memory: 583  loss: 1.5219\n",
      "11/16 19:37:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1000/1563]  lr: 1.0000e-03  eta: 0:00:30  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.4401\n",
      "11/16 19:37:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1010/1563]  lr: 1.0000e-03  eta: 0:00:29  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.5296\n",
      "11/16 19:37:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1020/1563]  lr: 1.0000e-03  eta: 0:00:29  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.5026\n",
      "11/16 19:37:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1030/1563]  lr: 1.0000e-03  eta: 0:00:28  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.4996\n",
      "11/16 19:37:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1040/1563]  lr: 1.0000e-03  eta: 0:00:27  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.5231\n",
      "11/16 19:37:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1050/1563]  lr: 1.0000e-03  eta: 0:00:27  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.4268\n",
      "11/16 19:37:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1060/1563]  lr: 1.0000e-03  eta: 0:00:26  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5333\n",
      "11/16 19:37:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1070/1563]  lr: 1.0000e-03  eta: 0:00:26  time: 0.0523  data_time: 0.0134  memory: 583  loss: 1.3655\n",
      "11/16 19:37:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1080/1563]  lr: 1.0000e-03  eta: 0:00:25  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.5330\n",
      "11/16 19:37:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1090/1563]  lr: 1.0000e-03  eta: 0:00:25  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.5190\n",
      "11/16 19:37:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1100/1563]  lr: 1.0000e-03  eta: 0:00:24  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5310\n",
      "11/16 19:37:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1110/1563]  lr: 1.0000e-03  eta: 0:00:24  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.6061\n",
      "11/16 19:37:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1120/1563]  lr: 1.0000e-03  eta: 0:00:23  time: 0.0524  data_time: 0.0137  memory: 583  loss: 1.4444\n",
      "11/16 19:37:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1130/1563]  lr: 1.0000e-03  eta: 0:00:23  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.3861\n",
      "11/16 19:37:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1140/1563]  lr: 1.0000e-03  eta: 0:00:22  time: 0.0524  data_time: 0.0137  memory: 583  loss: 1.4380\n",
      "11/16 19:37:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1150/1563]  lr: 1.0000e-03  eta: 0:00:22  time: 0.0523  data_time: 0.0136  memory: 583  loss: 1.5193\n",
      "11/16 19:37:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1160/1563]  lr: 1.0000e-03  eta: 0:00:21  time: 0.0518  data_time: 0.0133  memory: 583  loss: 1.5001\n",
      "11/16 19:37:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1170/1563]  lr: 1.0000e-03  eta: 0:00:21  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.4448\n",
      "11/16 19:37:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1180/1563]  lr: 1.0000e-03  eta: 0:00:20  time: 0.0521  data_time: 0.0135  memory: 583  loss: 1.5808\n",
      "11/16 19:37:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1190/1563]  lr: 1.0000e-03  eta: 0:00:19  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.5503\n",
      "11/16 19:37:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1200/1563]  lr: 1.0000e-03  eta: 0:00:19  time: 0.0518  data_time: 0.0132  memory: 583  loss: 1.4549\n",
      "11/16 19:37:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1210/1563]  lr: 1.0000e-03  eta: 0:00:18  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.5404\n",
      "11/16 19:37:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1220/1563]  lr: 1.0000e-03  eta: 0:00:18  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.6810\n",
      "11/16 19:37:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1230/1563]  lr: 1.0000e-03  eta: 0:00:17  time: 0.0521  data_time: 0.0136  memory: 583  loss: 1.4515\n",
      "11/16 19:37:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1240/1563]  lr: 1.0000e-03  eta: 0:00:17  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.5025\n",
      "11/16 19:37:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1250/1563]  lr: 1.0000e-03  eta: 0:00:16  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.5501\n",
      "11/16 19:37:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1260/1563]  lr: 1.0000e-03  eta: 0:00:16  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.4776\n",
      "11/16 19:37:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1270/1563]  lr: 1.0000e-03  eta: 0:00:15  time: 0.0518  data_time: 0.0132  memory: 583  loss: 1.4217\n",
      "11/16 19:37:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1280/1563]  lr: 1.0000e-03  eta: 0:00:15  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.4721\n",
      "11/16 19:37:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1290/1563]  lr: 1.0000e-03  eta: 0:00:14  time: 0.0522  data_time: 0.0135  memory: 583  loss: 1.4576\n",
      "11/16 19:37:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1300/1563]  lr: 1.0000e-03  eta: 0:00:14  time: 0.0513  data_time: 0.0133  memory: 583  loss: 1.3825\n",
      "11/16 19:37:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1310/1563]  lr: 1.0000e-03  eta: 0:00:13  time: 0.0525  data_time: 0.0138  memory: 583  loss: 1.4888\n",
      "11/16 19:37:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1320/1563]  lr: 1.0000e-03  eta: 0:00:12  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.3870\n",
      "11/16 19:37:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1330/1563]  lr: 1.0000e-03  eta: 0:00:12  time: 0.0529  data_time: 0.0137  memory: 583  loss: 1.6107\n",
      "11/16 19:37:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1340/1563]  lr: 1.0000e-03  eta: 0:00:11  time: 0.0555  data_time: 0.0146  memory: 583  loss: 1.5175\n",
      "11/16 19:37:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1350/1563]  lr: 1.0000e-03  eta: 0:00:11  time: 0.0556  data_time: 0.0144  memory: 583  loss: 1.4579\n",
      "11/16 19:37:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1360/1563]  lr: 1.0000e-03  eta: 0:00:10  time: 0.0554  data_time: 0.0144  memory: 583  loss: 1.4369\n",
      "11/16 19:37:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1370/1563]  lr: 1.0000e-03  eta: 0:00:10  time: 0.0557  data_time: 0.0145  memory: 583  loss: 1.3232\n",
      "11/16 19:37:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1380/1563]  lr: 1.0000e-03  eta: 0:00:09  time: 0.0556  data_time: 0.0146  memory: 583  loss: 1.4291\n",
      "11/16 19:37:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1390/1563]  lr: 1.0000e-03  eta: 0:00:09  time: 0.0546  data_time: 0.0143  memory: 583  loss: 1.5174\n",
      "11/16 19:37:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1400/1563]  lr: 1.0000e-03  eta: 0:00:08  time: 0.0534  data_time: 0.0138  memory: 583  loss: 1.5390\n",
      "11/16 19:37:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1410/1563]  lr: 1.0000e-03  eta: 0:00:08  time: 0.0518  data_time: 0.0134  memory: 583  loss: 1.5225\n",
      "11/16 19:37:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1420/1563]  lr: 1.0000e-03  eta: 0:00:07  time: 0.0521  data_time: 0.0134  memory: 583  loss: 1.3912\n",
      "11/16 19:37:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1430/1563]  lr: 1.0000e-03  eta: 0:00:07  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.5429\n",
      "11/16 19:37:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1440/1563]  lr: 1.0000e-03  eta: 0:00:06  time: 0.0520  data_time: 0.0133  memory: 583  loss: 1.5281\n",
      "11/16 19:37:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1450/1563]  lr: 1.0000e-03  eta: 0:00:06  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.5734\n",
      "11/16 19:37:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1460/1563]  lr: 1.0000e-03  eta: 0:00:05  time: 0.0524  data_time: 0.0135  memory: 583  loss: 1.4923\n",
      "11/16 19:37:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1470/1563]  lr: 1.0000e-03  eta: 0:00:04  time: 0.0520  data_time: 0.0135  memory: 583  loss: 1.4860\n",
      "11/16 19:37:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1480/1563]  lr: 1.0000e-03  eta: 0:00:04  time: 0.0517  data_time: 0.0133  memory: 583  loss: 1.3867\n",
      "11/16 19:37:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1490/1563]  lr: 1.0000e-03  eta: 0:00:03  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.5023\n",
      "11/16 19:37:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1500/1563]  lr: 1.0000e-03  eta: 0:00:03  time: 0.0519  data_time: 0.0134  memory: 583  loss: 1.5159\n",
      "11/16 19:37:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1510/1563]  lr: 1.0000e-03  eta: 0:00:02  time: 0.0515  data_time: 0.0133  memory: 583  loss: 1.5236\n",
      "11/16 19:37:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1520/1563]  lr: 1.0000e-03  eta: 0:00:02  time: 0.0520  data_time: 0.0134  memory: 583  loss: 1.4562\n",
      "11/16 19:37:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1530/1563]  lr: 1.0000e-03  eta: 0:00:01  time: 0.0524  data_time: 0.0136  memory: 583  loss: 1.3925\n",
      "11/16 19:37:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1540/1563]  lr: 1.0000e-03  eta: 0:00:01  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.4927\n",
      "11/16 19:37:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1550/1563]  lr: 1.0000e-03  eta: 0:00:00  time: 0.0523  data_time: 0.0135  memory: 583  loss: 1.4950\n",
      "11/16 19:37:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1560/1563]  lr: 1.0000e-03  eta: 0:00:00  time: 0.0519  data_time: 0.0133  memory: 583  loss: 1.5727\n",
      "11/16 19:37:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241116_193032\n",
      "11/16 19:37:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Saving checkpoint at 5 epochs\n",
      "11/16 19:37:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 10/313]    eta: 0:00:05  time: 0.0180  data_time: 0.0097  memory: 583  \n",
      "11/16 19:37:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 20/313]    eta: 0:00:05  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 30/313]    eta: 0:00:04  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 40/313]    eta: 0:00:04  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 50/313]    eta: 0:00:04  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 60/313]    eta: 0:00:04  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 70/313]    eta: 0:00:04  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 80/313]    eta: 0:00:03  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 90/313]    eta: 0:00:03  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][100/313]    eta: 0:00:03  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][110/313]    eta: 0:00:03  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][120/313]    eta: 0:00:03  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][130/313]    eta: 0:00:03  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][140/313]    eta: 0:00:02  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][150/313]    eta: 0:00:02  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][160/313]    eta: 0:00:02  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][170/313]    eta: 0:00:02  time: 0.0164  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][180/313]    eta: 0:00:02  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][190/313]    eta: 0:00:02  time: 0.0167  data_time: 0.0084  memory: 424  \n",
      "11/16 19:37:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][200/313]    eta: 0:00:01  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][210/313]    eta: 0:00:01  time: 0.0166  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][220/313]    eta: 0:00:01  time: 0.0166  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][230/313]    eta: 0:00:01  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][240/313]    eta: 0:00:01  time: 0.0166  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][250/313]    eta: 0:00:01  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][260/313]    eta: 0:00:00  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][270/313]    eta: 0:00:00  time: 0.0169  data_time: 0.0084  memory: 424  \n",
      "11/16 19:37:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][280/313]    eta: 0:00:00  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][290/313]    eta: 0:00:00  time: 0.0164  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][300/313]    eta: 0:00:00  time: 0.0165  data_time: 0.0082  memory: 424  \n",
      "11/16 19:37:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][310/313]    eta: 0:00:00  time: 0.0167  data_time: 0.0083  memory: 424  \n",
      "11/16 19:37:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][313/313]    accuracy: 50.1800  data_time: 0.0083  time: 0.0166\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "MMResNet50(\n",
       "  (data_preprocessor): BaseDataPreprocessor()\n",
       "  (resnet): ResNet(\n",
       "    (conv1): Conv2d(3, 64, kernel_size=(7, 7), stride=(2, 2), padding=(3, 3), bias=False)\n",
       "    (bn1): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "    (relu): ReLU(inplace=True)\n",
       "    (maxpool): MaxPool2d(kernel_size=3, stride=2, padding=1, dilation=1, ceil_mode=False)\n",
       "    (layer1): Sequential(\n",
       "      (0): Bottleneck(\n",
       "        (conv1): Conv2d(64, 64, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(64, 64, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(64, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "        (downsample): Sequential(\n",
       "          (0): Conv2d(64, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "          (1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        )\n",
       "      )\n",
       "      (1): Bottleneck(\n",
       "        (conv1): Conv2d(256, 64, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(64, 64, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(64, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (2): Bottleneck(\n",
       "        (conv1): Conv2d(256, 64, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(64, 64, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(64, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "    )\n",
       "    (layer2): Sequential(\n",
       "      (0): Bottleneck(\n",
       "        (conv1): Conv2d(256, 128, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(128, 128, kernel_size=(3, 3), stride=(2, 2), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(128, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "        (downsample): Sequential(\n",
       "          (0): Conv2d(256, 512, kernel_size=(1, 1), stride=(2, 2), bias=False)\n",
       "          (1): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        )\n",
       "      )\n",
       "      (1): Bottleneck(\n",
       "        (conv1): Conv2d(512, 128, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(128, 128, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(128, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (2): Bottleneck(\n",
       "        (conv1): Conv2d(512, 128, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(128, 128, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(128, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (3): Bottleneck(\n",
       "        (conv1): Conv2d(512, 128, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(128, 128, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(128, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "    )\n",
       "    (layer3): Sequential(\n",
       "      (0): Bottleneck(\n",
       "        (conv1): Conv2d(512, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(2, 2), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "        (downsample): Sequential(\n",
       "          (0): Conv2d(512, 1024, kernel_size=(1, 1), stride=(2, 2), bias=False)\n",
       "          (1): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        )\n",
       "      )\n",
       "      (1): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (2): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (3): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (4): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (5): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "    )\n",
       "    (layer4): Sequential(\n",
       "      (0): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(512, 512, kernel_size=(3, 3), stride=(2, 2), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(512, 2048, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(2048, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "        (downsample): Sequential(\n",
       "          (0): Conv2d(1024, 2048, kernel_size=(1, 1), stride=(2, 2), bias=False)\n",
       "          (1): BatchNorm2d(2048, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        )\n",
       "      )\n",
       "      (1): Bottleneck(\n",
       "        (conv1): Conv2d(2048, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(512, 512, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(512, 2048, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(2048, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (2): Bottleneck(\n",
       "        (conv1): Conv2d(2048, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(512, 512, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(512, 2048, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(2048, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "    )\n",
       "    (avgpool): AdaptiveAvgPool2d(output_size=(1, 1))\n",
       "    (fc): Linear(in_features=2048, out_features=1000, bias=True)\n",
       "  )\n",
       ")"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "from torch.optim import SGD\n",
    "from mmengine.runner import Runner\n",
    "\n",
    "runner = Runner(\n",
    "    # 用以训练和验证的模型，需要满足特定的接口需求\n",
    "    model=MMResNet50(),\n",
    "    # 工作路径，用以保存训练日志、权重文件信息\n",
    "    work_dir=temp_dir/'./work_dir',\n",
    "    # 训练数据加载器，需要满足 PyTorch 数据加载器协议\n",
    "    train_dataloader=train_dataloader,\n",
    "    # 优化器包装，用于模型优化，并提供 AMP、梯度累积等附加功能\n",
    "    optim_wrapper=dict(optimizer=dict(type=SGD, lr=0.001, momentum=0.9)),\n",
    "    # 训练配置，用于指定训练周期、验证间隔等信息\n",
    "    train_cfg=dict(by_epoch=True, max_epochs=5, val_interval=1),\n",
    "    # 验证数据加载器，需要满足 PyTorch 数据加载器协议\n",
    "    val_dataloader=val_dataloader,\n",
    "    # 验证配置，用于指定验证所需要的额外参数\n",
    "    val_cfg=dict(),\n",
    "    # 用于验证的评测器，这里使用默认评测器，并评测指标\n",
    "    val_evaluator=dict(type=Accuracy),\n",
    ")\n",
    "\n",
    "runner.train()"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.12.2"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
